import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse
from typing_extensions import Self

from peertube.models.videos_for_xml_item_mediarating import VideosForXMLItemMediarating
from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.mrss_group_content import MRSSGroupContent
    from peertube.models.mrss_peer_link import MRSSPeerLink
    from peertube.models.videos_for_xml_item_enclosure import VideosForXMLItemEnclosure
    from peertube.models.videos_for_xml_item_mediacommunity import (
        VideosForXMLItemMediacommunity,
    )
    from peertube.models.videos_for_xml_item_mediaembed import (
        VideosForXMLItemMediaembed,
    )
    from peertube.models.videos_for_xml_item_mediaplayer import (
        VideosForXMLItemMediaplayer,
    )
    from peertube.models.videos_for_xml_item_mediathumbnail import (
        VideosForXMLItemMediathumbnail,
    )


T = TypeVar("T", bound="VideosForXMLItem")


@_attrs_define
class VideosForXMLItem:
    """Attributes:
    link (Union[Unset, str]): video watch page URL
    guid (Union[Unset, str]): video canonical URL
    pub_date (Union[Unset, datetime.datetime]): video publication date
    description (Union[Unset, str]): video description
    contentencoded (Union[Unset, str]): video description
    dccreator (Union[Unset, str]): publisher user name
    mediacategory (Union[Unset, int]): video category (MRSS)
    mediacommunity (Union[Unset, VideosForXMLItemMediacommunity]): see
        [media:community](https://www.rssboard.org/media-rss#media-community) (MRSS)
    mediaembed (Union[Unset, VideosForXMLItemMediaembed]):
    mediaplayer (Union[Unset, VideosForXMLItemMediaplayer]):
    mediathumbnail (Union[Unset, VideosForXMLItemMediathumbnail]):
    mediatitle (Union[Unset, str]): see [media:title](https://www.rssboard.org/media-rss#media-title) (MRSS). We
        only use `plain` titles.
    mediadescription (Union[Unset, str]):
    mediarating (Union[Unset, VideosForXMLItemMediarating]): see [media:rating](https://www.rssboard.org/media-
        rss#media-rating) (MRSS)
    enclosure (Union[Unset, VideosForXMLItemEnclosure]): main streamable file for the video
    mediagroup (Union[Unset, list[Union['MRSSGroupContent', 'MRSSPeerLink']]]): list of streamable files for the
        video. see [media:peerLink](https://www.rssboard.org/media-rss#media-peerlink) and
        [media:content](https://www.rssboard.org/media-rss#media-content) or  (MRSS)
    """

    link: Unset | str = UNSET
    guid: Unset | str = UNSET
    pub_date: Unset | datetime.datetime = UNSET
    description: Unset | str = UNSET
    contentencoded: Unset | str = UNSET
    dccreator: Unset | str = UNSET
    mediacategory: Unset | int = UNSET
    mediacommunity: Union[Unset, "VideosForXMLItemMediacommunity"] = UNSET
    mediaembed: Union[Unset, "VideosForXMLItemMediaembed"] = UNSET
    mediaplayer: Union[Unset, "VideosForXMLItemMediaplayer"] = UNSET
    mediathumbnail: Union[Unset, "VideosForXMLItemMediathumbnail"] = UNSET
    mediatitle: Unset | str = UNSET
    mediadescription: Unset | str = UNSET
    mediarating: Unset | VideosForXMLItemMediarating = UNSET
    enclosure: Union[Unset, "VideosForXMLItemEnclosure"] = UNSET
    mediagroup: Unset | list[Union["MRSSGroupContent", "MRSSPeerLink"]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        from peertube.models.mrss_peer_link import MRSSPeerLink

        link = self.link

        guid = self.guid

        pub_date: Unset | str = UNSET
        if not isinstance(self.pub_date, Unset):
            pub_date = self.pub_date.isoformat()

        description = self.description

        contentencoded = self.contentencoded

        dccreator = self.dccreator

        mediacategory = self.mediacategory

        mediacommunity: Unset | dict[str, Any] = UNSET
        if not isinstance(self.mediacommunity, Unset):
            mediacommunity = self.mediacommunity.to_dict()

        mediaembed: Unset | dict[str, Any] = UNSET
        if not isinstance(self.mediaembed, Unset):
            mediaembed = self.mediaembed.to_dict()

        mediaplayer: Unset | dict[str, Any] = UNSET
        if not isinstance(self.mediaplayer, Unset):
            mediaplayer = self.mediaplayer.to_dict()

        mediathumbnail: Unset | dict[str, Any] = UNSET
        if not isinstance(self.mediathumbnail, Unset):
            mediathumbnail = self.mediathumbnail.to_dict()

        mediatitle = self.mediatitle

        mediadescription = self.mediadescription

        mediarating: Unset | str = UNSET
        if not isinstance(self.mediarating, Unset):
            mediarating = self.mediarating.value

        enclosure: Unset | dict[str, Any] = UNSET
        if not isinstance(self.enclosure, Unset):
            enclosure = self.enclosure.to_dict()

        mediagroup: Unset | list[dict[str, Any]] = UNSET
        if not isinstance(self.mediagroup, Unset):
            mediagroup = []
            for mediagroup_item_data in self.mediagroup:
                mediagroup_item: dict[str, Any]
                if isinstance(mediagroup_item_data, MRSSPeerLink):
                    mediagroup_item = mediagroup_item_data.to_dict()
                else:
                    mediagroup_item = mediagroup_item_data.to_dict()

                mediagroup.append(mediagroup_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if link is not UNSET:
            field_dict["link"] = link
        if guid is not UNSET:
            field_dict["guid"] = guid
        if pub_date is not UNSET:
            field_dict["pubDate"] = pub_date
        if description is not UNSET:
            field_dict["description"] = description
        if contentencoded is not UNSET:
            field_dict["content:encoded"] = contentencoded
        if dccreator is not UNSET:
            field_dict["dc:creator"] = dccreator
        if mediacategory is not UNSET:
            field_dict["media:category"] = mediacategory
        if mediacommunity is not UNSET:
            field_dict["media:community"] = mediacommunity
        if mediaembed is not UNSET:
            field_dict["media:embed"] = mediaembed
        if mediaplayer is not UNSET:
            field_dict["media:player"] = mediaplayer
        if mediathumbnail is not UNSET:
            field_dict["media:thumbnail"] = mediathumbnail
        if mediatitle is not UNSET:
            field_dict["media:title"] = mediatitle
        if mediadescription is not UNSET:
            field_dict["media:description"] = mediadescription
        if mediarating is not UNSET:
            field_dict["media:rating"] = mediarating
        if enclosure is not UNSET:
            field_dict["enclosure"] = enclosure
        if mediagroup is not UNSET:
            field_dict["media:group"] = mediagroup

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.mrss_group_content import MRSSGroupContent
        from peertube.models.mrss_peer_link import MRSSPeerLink
        from peertube.models.videos_for_xml_item_enclosure import (
            VideosForXMLItemEnclosure,
        )
        from peertube.models.videos_for_xml_item_mediacommunity import (
            VideosForXMLItemMediacommunity,
        )
        from peertube.models.videos_for_xml_item_mediaembed import (
            VideosForXMLItemMediaembed,
        )
        from peertube.models.videos_for_xml_item_mediaplayer import (
            VideosForXMLItemMediaplayer,
        )
        from peertube.models.videos_for_xml_item_mediathumbnail import (
            VideosForXMLItemMediathumbnail,
        )

        d = dict(src_dict)
        link = d.pop("link", UNSET)

        guid = d.pop("guid", UNSET)

        _pub_date = d.pop("pubDate", UNSET)
        pub_date: Unset | datetime.datetime
        if isinstance(_pub_date, Unset):
            pub_date = UNSET
        else:
            pub_date = isoparse(_pub_date)

        description = d.pop("description", UNSET)

        contentencoded = d.pop("content:encoded", UNSET)

        dccreator = d.pop("dc:creator", UNSET)

        mediacategory = d.pop("media:category", UNSET)

        _mediacommunity = d.pop("media:community", UNSET)
        mediacommunity: Unset | VideosForXMLItemMediacommunity
        if isinstance(_mediacommunity, Unset):
            mediacommunity = UNSET
        else:
            mediacommunity = VideosForXMLItemMediacommunity.from_dict(_mediacommunity)

        _mediaembed = d.pop("media:embed", UNSET)
        mediaembed: Unset | VideosForXMLItemMediaembed
        if isinstance(_mediaembed, Unset):
            mediaembed = UNSET
        else:
            mediaembed = VideosForXMLItemMediaembed.from_dict(_mediaembed)

        _mediaplayer = d.pop("media:player", UNSET)
        mediaplayer: Unset | VideosForXMLItemMediaplayer
        if isinstance(_mediaplayer, Unset):
            mediaplayer = UNSET
        else:
            mediaplayer = VideosForXMLItemMediaplayer.from_dict(_mediaplayer)

        _mediathumbnail = d.pop("media:thumbnail", UNSET)
        mediathumbnail: Unset | VideosForXMLItemMediathumbnail
        if isinstance(_mediathumbnail, Unset):
            mediathumbnail = UNSET
        else:
            mediathumbnail = VideosForXMLItemMediathumbnail.from_dict(_mediathumbnail)

        mediatitle = d.pop("media:title", UNSET)

        mediadescription = d.pop("media:description", UNSET)

        _mediarating = d.pop("media:rating", UNSET)
        mediarating: Unset | VideosForXMLItemMediarating
        if isinstance(_mediarating, Unset):
            mediarating = UNSET
        else:
            mediarating = VideosForXMLItemMediarating(_mediarating)

        _enclosure = d.pop("enclosure", UNSET)
        enclosure: Unset | VideosForXMLItemEnclosure
        if isinstance(_enclosure, Unset):
            enclosure = UNSET
        else:
            enclosure = VideosForXMLItemEnclosure.from_dict(_enclosure)

        mediagroup = []
        _mediagroup = d.pop("media:group", UNSET)
        for mediagroup_item_data in _mediagroup or []:

            def _parse_mediagroup_item(
                data: object,
            ) -> Union["MRSSGroupContent", "MRSSPeerLink"]:
                try:
                    if not isinstance(data, dict):
                        raise TypeError
                    mediagroup_item_type_0 = MRSSPeerLink.from_dict(data)

                    return mediagroup_item_type_0
                except:  # noqa: E722
                    pass
                if not isinstance(data, dict):
                    raise TypeError
                mediagroup_item_type_1 = MRSSGroupContent.from_dict(data)

                return mediagroup_item_type_1

            mediagroup_item = _parse_mediagroup_item(mediagroup_item_data)

            mediagroup.append(mediagroup_item)

        videos_for_xml_item = cls(
            link=link,
            guid=guid,
            pub_date=pub_date,
            description=description,
            contentencoded=contentencoded,
            dccreator=dccreator,
            mediacategory=mediacategory,
            mediacommunity=mediacommunity,
            mediaembed=mediaembed,
            mediaplayer=mediaplayer,
            mediathumbnail=mediathumbnail,
            mediatitle=mediatitle,
            mediadescription=mediadescription,
            mediarating=mediarating,
            enclosure=enclosure,
            mediagroup=mediagroup,
        )

        videos_for_xml_item.additional_properties = d
        return videos_for_xml_item

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import IntEnum


class UserExportState(IntEnum):
    """UserExportState enumeration."""

    VALUE_1 = 1
    VALUE_2 = 2
    VALUE_3 = 3
    VALUE_4 = 4

    def __str__(self) -> str:
        return str(self.value)



from typing import Any
from uuid import UUID

import httpx

from peertube import errors
from peertube.api.shared_utils import build_response
from peertube.client import AuthenticatedClient, Client
from peertube.types import UNSET, File, Response


def _get_kwargs(
    id: UUID | int | str,
    *,
    body: File,
    upload_id: str,
    content_range: str,
    content_length: float,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}
    headers["Content-Range"] = content_range
    headers["Content-Length"] = str(content_length)

    params: dict[str, Any] = {}

    params["upload_id"] = upload_id
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "put",
        "url": f"/api/v1/videos/{id}/source/replace-resumable",
        "params": params,
    }

    _kwargs["content"] = body.payload

    headers["Content-Type"] = "application/octet-stream"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Any | None:
    if response.status_code == 204:
        return None

    if response.status_code == 308:
        return None

    if response.status_code == 403:
        return None

    if response.status_code == 404:
        return None

    if response.status_code == 409:
        return None

    if response.status_code == 422:
        return None

    if response.status_code == 429:
        return None

    if response.status_code == 503:
        return None
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[Any]:
    return build_response(client=client, response=response)


def sync_detailed(
    id: UUID | int | str,
    *,
    client: AuthenticatedClient,
    body: File,
    upload_id: str,
    content_range: str,
    content_length: float,
) -> Response[Any]:
    """Send chunk for the resumable replacement of a video
     **PeerTube > = 6.0** Uses [a resumable protocol](https://github.com/kukhariev/node-
    uploadx/blob/master/proto.md) to continue, pause or resume the replacement of a video

    Args:
        id (Union[UUID, int, str]): Unique identifier for the entity.
        upload_id (str): Parameter for upload id.
        content_range (str):  Example: bytes 0-262143/2469036.
        content_length (float):  Example: 262144.
        body (File): Request body data.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        id=id,
        body=body,
        upload_id=upload_id,
        content_range=content_range,
        content_length=content_length,
    )

    response = client.get_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    id: UUID | int | str,
    *,
    client: AuthenticatedClient,
    body: File,
    upload_id: str,
    content_range: str,
    content_length: float,
) -> Any | None:
    """Send chunk for the resumable replacement of a video


    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Any
    """

    return sync_detailed(
        id=id,
        client=client,
        body=body,
        upload_id=upload_id,
        content_range=content_range,
        content_length=content_length,
    ).parsed


async def asyncio_detailed(
    id: UUID | int | str,
    *,
    client: AuthenticatedClient,
    body: File,
    upload_id: str,
    content_range: str,
    content_length: float,
) -> Response[Any]:
    """Send chunk for the resumable replacement of a video
     **PeerTube > = 6.0** Uses [a resumable protocol](https://github.com/kukhariev/node-
    uploadx/blob/master/proto.md) to continue, pause or resume the replacement of a video

    Args:
        id (Union[UUID, int, str]): Unique identifier for the entity.
        upload_id (str): Parameter for upload id.
        content_range (str):  Example: bytes 0-262143/2469036.
        content_length (float):  Example: 262144.
        body (File): Request body data.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        id=id,
        body=body,
        upload_id=upload_id,
        content_range=content_range,
        content_length=content_length,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)



from http import HTTPStatus
from typing import Any

import httpx

from peertube import errors
from peertube.client import AuthenticatedClient, Client
from peertube.models.get_video_channel_videos_include import (
    GetVideoChannelVideosInclude,
)
from peertube.models.get_video_channel_videos_nsfw import GetVideoChannelVideosNsfw
from peertube.models.get_video_channel_videos_skip_count import (
    GetVideoChannelVideosSkipCount,
)
from peertube.models.get_video_channel_videos_sort import GetVideoChannelVideosSort
from peertube.models.nsfw_flag import NSFWFlag
from peertube.models.video_list_response import VideoListResponse
from peertube.models.video_privacy_set import VideoPrivacySet
from peertube.types import UNSET, Response, Unset


def _get_kwargs(
    channel_handle: str,
    *,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    skip_count: Unset
    | GetVideoChannelVideosSkipCount = GetVideoChannelVideosSkipCount.FALSE,
    sort: Unset | GetVideoChannelVideosSort = UNSET,
    nsfw: Unset | GetVideoChannelVideosNsfw = UNSET,
    nsfw_flags_included: Unset | NSFWFlag = UNSET,
    nsfw_flags_excluded: Unset | NSFWFlag = UNSET,
    is_live: Unset | bool = UNSET,
    include_scheduled_live: Unset | bool = UNSET,
    category_one_of: Unset | int | list[int] = UNSET,
    licence_one_of: Unset | int | list[int] = UNSET,
    language_one_of: Unset | list[str] | str = UNSET,
    tags_one_of: Unset | list[str] | str = UNSET,
    tags_all_of: Unset | list[str] | str = UNSET,
    is_local: Unset | bool = UNSET,
    include: Unset | GetVideoChannelVideosInclude = UNSET,
    has_hls_files: Unset | bool = UNSET,
    has_web_video_files: Unset | bool = UNSET,
    host: Unset | str = UNSET,
    auto_tag_one_of: Unset | list[str] | str = UNSET,
    privacy_one_of: Unset | VideoPrivacySet = UNSET,
    exclude_already_watched: Unset | bool = UNSET,
    search: Unset | str = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["start"] = start

    params["count"] = count
    json_skip_count: Unset | str = UNSET
    if not isinstance(skip_count, Unset):
        json_skip_count = skip_count.value

    params["skipCount"] = json_skip_count
    json_sort: Unset | str = UNSET
    if not isinstance(sort, Unset):
        json_sort = sort.value

    params["sort"] = json_sort
    json_nsfw: Unset | str = UNSET
    if not isinstance(nsfw, Unset):
        json_nsfw = nsfw.value

    params["nsfw"] = json_nsfw
    json_nsfw_flags_included: Unset | int = UNSET
    if not isinstance(nsfw_flags_included, Unset):
        json_nsfw_flags_included = nsfw_flags_included.value

    params["nsfwFlagsIncluded"] = json_nsfw_flags_included
    json_nsfw_flags_excluded: Unset | int = UNSET
    if not isinstance(nsfw_flags_excluded, Unset):
        json_nsfw_flags_excluded = nsfw_flags_excluded.value

    params["nsfwFlagsExcluded"] = json_nsfw_flags_excluded

    params["isLive"] = is_live

    params["includeScheduledLive"] = include_scheduled_live
    json_category_one_of: Unset | int | list[int]
    if isinstance(category_one_of, Unset):
        json_category_one_of = UNSET
    elif isinstance(category_one_of, list):
        json_category_one_of = category_one_of

    else:
        json_category_one_of = category_one_of
    params["categoryOneOf"] = json_category_one_of
    json_licence_one_of: Unset | int | list[int]
    if isinstance(licence_one_of, Unset):
        json_licence_one_of = UNSET
    elif isinstance(licence_one_of, list):
        json_licence_one_of = licence_one_of

    else:
        json_licence_one_of = licence_one_of
    params["licenceOneOf"] = json_licence_one_of
    json_language_one_of: Unset | list[str] | str
    if isinstance(language_one_of, Unset):
        json_language_one_of = UNSET
    elif isinstance(language_one_of, list):
        json_language_one_of = language_one_of

    else:
        json_language_one_of = language_one_of
    params["languageOneOf"] = json_language_one_of
    json_tags_one_of: Unset | list[str] | str
    if isinstance(tags_one_of, Unset):
        json_tags_one_of = UNSET
    elif isinstance(tags_one_of, list):
        json_tags_one_of = tags_one_of

    else:
        json_tags_one_of = tags_one_of
    params["tagsOneOf"] = json_tags_one_of
    json_tags_all_of: Unset | list[str] | str
    if isinstance(tags_all_of, Unset):
        json_tags_all_of = UNSET
    elif isinstance(tags_all_of, list):
        json_tags_all_of = tags_all_of

    else:
        json_tags_all_of = tags_all_of
    params["tagsAllOf"] = json_tags_all_of

    params["isLocal"] = is_local
    json_include: Unset | int = UNSET
    if not isinstance(include, Unset):
        json_include = include.value

    params["include"] = json_include

    params["hasHLSFiles"] = has_hls_files

    params["hasWebVideoFiles"] = has_web_video_files

    params["host"] = host
    json_auto_tag_one_of: Unset | list[str] | str
    if isinstance(auto_tag_one_of, Unset):
        json_auto_tag_one_of = UNSET
    elif isinstance(auto_tag_one_of, list):
        json_auto_tag_one_of = auto_tag_one_of

    else:
        json_auto_tag_one_of = auto_tag_one_of
    params["autoTagOneOf"] = json_auto_tag_one_of
    json_privacy_one_of: Unset | int = UNSET
    if not isinstance(privacy_one_of, Unset):
        json_privacy_one_of = privacy_one_of.value

    params["privacyOneOf"] = json_privacy_one_of

    params["excludeAlreadyWatched"] = exclude_already_watched

    params["search"] = search
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/api/v1/video-channels/{channel_handle}/videos",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> VideoListResponse | None:
    if response.status_code == 200:
        response_200 = VideoListResponse.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[VideoListResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    channel_handle: str,
    *,
    client: AuthenticatedClient | Client,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    skip_count: Unset
    | GetVideoChannelVideosSkipCount = GetVideoChannelVideosSkipCount.FALSE,
    sort: Unset | GetVideoChannelVideosSort = UNSET,
    nsfw: Unset | GetVideoChannelVideosNsfw = UNSET,
    nsfw_flags_included: Unset | NSFWFlag = UNSET,
    nsfw_flags_excluded: Unset | NSFWFlag = UNSET,
    is_live: Unset | bool = UNSET,
    include_scheduled_live: Unset | bool = UNSET,
    category_one_of: Unset | int | list[int] = UNSET,
    licence_one_of: Unset | int | list[int] = UNSET,
    language_one_of: Unset | list[str] | str = UNSET,
    tags_one_of: Unset | list[str] | str = UNSET,
    tags_all_of: Unset | list[str] | str = UNSET,
    is_local: Unset | bool = UNSET,
    include: Unset | GetVideoChannelVideosInclude = UNSET,
    has_hls_files: Unset | bool = UNSET,
    has_web_video_files: Unset | bool = UNSET,
    host: Unset | str = UNSET,
    auto_tag_one_of: Unset | list[str] | str = UNSET,
    privacy_one_of: Unset | VideoPrivacySet = UNSET,
    exclude_already_watched: Unset | bool = UNSET,
    search: Unset | str = UNSET,
) -> Response[VideoListResponse]:
    """List videos of a video channel


    Args:
        channel_handle (str):  Example: my_username | my_username@example.com.
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        skip_count (Union[Unset, GetVideoChannelVideosSkipCount]):  Default:
            GetVideoChannelVideosSkipCount.FALSE.
        sort (Union[Unset, GetVideoChannelVideosSort]): Sort videos by criteria (prefixing with
            `-` means `DESC` order):
              * `hot` - Adaptation of Reddit "hot" algorithm taking into account video views, likes, dislikes and comments and publication date
              * `best` - Same than `hot`, but also takes into account user video history
              * `trending` - Sort videos by recent views ("recent" is defined by the admin)
              * `views` - Sort videos using their `views` counter
              * `publishedAt` - Sort by video publication date (when it became publicly available)
        nsfw (Union[Unset, GetVideoChannelVideosNsfw]): Parameter for nsfw.
        nsfw_flags_included (Union[Unset, NSFWFlag]): Parameter for nsfw flags included.
            NSFW flags (can be combined using bitwise or operator)
            - `0` NONE
            - `1` VIOLENT
            - `2` EXPLICIT_SEX
        nsfw_flags_excluded (Union[Unset, NSFWFlag]): Parameter for nsfw flags excluded.
            NSFW flags (can be combined using bitwise or operator)
            - `0` NONE
            - `1` VIOLENT
            - `2` EXPLICIT_SEX
        is_live (Union[Unset, bool]): Parameter for is live.
        include_scheduled_live (Union[Unset, bool]): Parameter for include scheduled live.
        category_one_of (Union[Unset, int, list[int]]): Parameter for category one of.
        licence_one_of (Union[Unset, int, list[int]]): Parameter for licence one of.
        language_one_of (Union[Unset, list[str], str]): Parameter for language one of.
        tags_one_of (Union[Unset, list[str], str]): Parameter for tags one of.
        tags_all_of (Union[Unset, list[str], str]): Parameter for tags all of.
        is_local (Union[Unset, bool]): Parameter for is local.
        include (Union[Unset, GetVideoChannelVideosInclude]): Parameter for include.
        has_hls_files (Union[Unset, bool]): Parameter for has hls files.
        has_web_video_files (Union[Unset, bool]): Video-related parameter.
        host (Union[Unset, str]): Parameter for host.
        auto_tag_one_of (Union[Unset, list[str], str]): Parameter for auto tag one of.
        privacy_one_of (Union[Unset, VideoPrivacySet]): privacy id of the video (see
            [/videos/privacies](#operation/getVideoPrivacyPolicies))
        exclude_already_watched (Union[Unset, bool]): Parameter for exclude already watched.
        search (Union[Unset, str]): Search query filter.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[VideoListResponse]
    """
    kwargs = _get_kwargs(
        channel_handle=channel_handle,
        start=start,
        count=count,
        skip_count=skip_count,
        sort=sort,
        nsfw=nsfw,
        nsfw_flags_included=nsfw_flags_included,
        nsfw_flags_excluded=nsfw_flags_excluded,
        is_live=is_live,
        include_scheduled_live=include_scheduled_live,
        category_one_of=category_one_of,
        licence_one_of=licence_one_of,
        language_one_of=language_one_of,
        tags_one_of=tags_one_of,
        tags_all_of=tags_all_of,
        is_local=is_local,
        include=include,
        has_hls_files=has_hls_files,
        has_web_video_files=has_web_video_files,
        host=host,
        auto_tag_one_of=auto_tag_one_of,
        privacy_one_of=privacy_one_of,
        exclude_already_watched=exclude_already_watched,
        search=search,
    )

    response = client.get_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    channel_handle: str,
    *,
    client: AuthenticatedClient | Client,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    skip_count: Unset
    | GetVideoChannelVideosSkipCount = GetVideoChannelVideosSkipCount.FALSE,
    sort: Unset | GetVideoChannelVideosSort = UNSET,
    nsfw: Unset | GetVideoChannelVideosNsfw = UNSET,
    nsfw_flags_included: Unset | NSFWFlag = UNSET,
    nsfw_flags_excluded: Unset | NSFWFlag = UNSET,
    is_live: Unset | bool = UNSET,
    include_scheduled_live: Unset | bool = UNSET,
    category_one_of: Unset | int | list[int] = UNSET,
    licence_one_of: Unset | int | list[int] = UNSET,
    language_one_of: Unset | list[str] | str = UNSET,
    tags_one_of: Unset | list[str] | str = UNSET,
    tags_all_of: Unset | list[str] | str = UNSET,
    is_local: Unset | bool = UNSET,
    include: Unset | GetVideoChannelVideosInclude = UNSET,
    has_hls_files: Unset | bool = UNSET,
    has_web_video_files: Unset | bool = UNSET,
    host: Unset | str = UNSET,
    auto_tag_one_of: Unset | list[str] | str = UNSET,
    privacy_one_of: Unset | VideoPrivacySet = UNSET,
    exclude_already_watched: Unset | bool = UNSET,
    search: Unset | str = UNSET,
) -> VideoListResponse | None:
    """List videos of a video channel


    Args:
        channel_handle (str):  Example: my_username | my_username@example.com.
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        skip_count (Union[Unset, GetVideoChannelVideosSkipCount]):  Default:
            GetVideoChannelVideosSkipCount.FALSE.
        sort (Union[Unset, GetVideoChannelVideosSort]): Sort videos by criteria (prefixing with
            `-` means `DESC` order):
              * `hot` - Adaptation of Reddit "hot" algorithm taking into account video views, likes, dislikes and comments and publication date
              * `best` - Same than `hot`, but also takes into account user video history
              * `trending` - Sort videos by recent views ("recent" is defined by the admin)
              * `views` - Sort videos using their `views` counter
              * `publishedAt` - Sort by video publication date (when it became publicly available)
        nsfw (Union[Unset, GetVideoChannelVideosNsfw]): Parameter for nsfw.
        nsfw_flags_included (Union[Unset, NSFWFlag]): Parameter for nsfw flags included.
            NSFW flags (can be combined using bitwise or operator)
            - `0` NONE
            - `1` VIOLENT
            - `2` EXPLICIT_SEX
        nsfw_flags_excluded (Union[Unset, NSFWFlag]): Parameter for nsfw flags excluded.
            NSFW flags (can be combined using bitwise or operator)
            - `0` NONE
            - `1` VIOLENT
            - `2` EXPLICIT_SEX
        is_live (Union[Unset, bool]): Parameter for is live.
        include_scheduled_live (Union[Unset, bool]): Parameter for include scheduled live.
        category_one_of (Union[Unset, int, list[int]]): Parameter for category one of.
        licence_one_of (Union[Unset, int, list[int]]): Parameter for licence one of.
        language_one_of (Union[Unset, list[str], str]): Parameter for language one of.
        tags_one_of (Union[Unset, list[str], str]): Parameter for tags one of.
        tags_all_of (Union[Unset, list[str], str]): Parameter for tags all of.
        is_local (Union[Unset, bool]): Parameter for is local.
        include (Union[Unset, GetVideoChannelVideosInclude]): Parameter for include.
        has_hls_files (Union[Unset, bool]): Parameter for has hls files.
        has_web_video_files (Union[Unset, bool]): Video-related parameter.
        host (Union[Unset, str]): Parameter for host.
        auto_tag_one_of (Union[Unset, list[str], str]): Parameter for auto tag one of.
        privacy_one_of (Union[Unset, VideoPrivacySet]): privacy id of the video (see
            [/videos/privacies](#operation/getVideoPrivacyPolicies))
        exclude_already_watched (Union[Unset, bool]): Parameter for exclude already watched.
        search (Union[Unset, str]): Search query filter.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        VideoListResponse
    """
    return sync_detailed(
        channel_handle=channel_handle,
        client=client,
        start=start,
        count=count,
        skip_count=skip_count,
        sort=sort,
        nsfw=nsfw,
        nsfw_flags_included=nsfw_flags_included,
        nsfw_flags_excluded=nsfw_flags_excluded,
        is_live=is_live,
        include_scheduled_live=include_scheduled_live,
        category_one_of=category_one_of,
        licence_one_of=licence_one_of,
        language_one_of=language_one_of,
        tags_one_of=tags_one_of,
        tags_all_of=tags_all_of,
        is_local=is_local,
        include=include,
        has_hls_files=has_hls_files,
        has_web_video_files=has_web_video_files,
        host=host,
        auto_tag_one_of=auto_tag_one_of,
        privacy_one_of=privacy_one_of,
        exclude_already_watched=exclude_already_watched,
        search=search,
    ).parsed


async def asyncio_detailed(
    channel_handle: str,
    *,
    client: AuthenticatedClient | Client,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    skip_count: Unset
    | GetVideoChannelVideosSkipCount = GetVideoChannelVideosSkipCount.FALSE,
    sort: Unset | GetVideoChannelVideosSort = UNSET,
    nsfw: Unset | GetVideoChannelVideosNsfw = UNSET,
    nsfw_flags_included: Unset | NSFWFlag = UNSET,
    nsfw_flags_excluded: Unset | NSFWFlag = UNSET,
    is_live: Unset | bool = UNSET,
    include_scheduled_live: Unset | bool = UNSET,
    category_one_of: Unset | int | list[int] = UNSET,
    licence_one_of: Unset | int | list[int] = UNSET,
    language_one_of: Unset | list[str] | str = UNSET,
    tags_one_of: Unset | list[str] | str = UNSET,
    tags_all_of: Unset | list[str] | str = UNSET,
    is_local: Unset | bool = UNSET,
    include: Unset | GetVideoChannelVideosInclude = UNSET,
    has_hls_files: Unset | bool = UNSET,
    has_web_video_files: Unset | bool = UNSET,
    host: Unset | str = UNSET,
    auto_tag_one_of: Unset | list[str] | str = UNSET,
    privacy_one_of: Unset | VideoPrivacySet = UNSET,
    exclude_already_watched: Unset | bool = UNSET,
    search: Unset | str = UNSET,
) -> Response[VideoListResponse]:
    """List videos of a video channel


    Args:
        channel_handle (str):  Example: my_username | my_username@example.com.
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        skip_count (Union[Unset, GetVideoChannelVideosSkipCount]):  Default:
            GetVideoChannelVideosSkipCount.FALSE.
        sort (Union[Unset, GetVideoChannelVideosSort]): Sort videos by criteria (prefixing with
            `-` means `DESC` order):
              * `hot` - Adaptation of Reddit "hot" algorithm taking into account video views, likes, dislikes and comments and publication date
              * `best` - Same than `hot`, but also takes into account user video history
              * `trending` - Sort videos by recent views ("recent" is defined by the admin)
              * `views` - Sort videos using their `views` counter
              * `publishedAt` - Sort by video publication date (when it became publicly available)
        nsfw (Union[Unset, GetVideoChannelVideosNsfw]): Parameter for nsfw.
        nsfw_flags_included (Union[Unset, NSFWFlag]): Parameter for nsfw flags included.
            NSFW flags (can be combined using bitwise or operator)
            - `0` NONE
            - `1` VIOLENT
            - `2` EXPLICIT_SEX
        nsfw_flags_excluded (Union[Unset, NSFWFlag]): Parameter for nsfw flags excluded.
            NSFW flags (can be combined using bitwise or operator)
            - `0` NONE
            - `1` VIOLENT
            - `2` EXPLICIT_SEX
        is_live (Union[Unset, bool]): Parameter for is live.
        include_scheduled_live (Union[Unset, bool]): Parameter for include scheduled live.
        category_one_of (Union[Unset, int, list[int]]): Parameter for category one of.
        licence_one_of (Union[Unset, int, list[int]]): Parameter for licence one of.
        language_one_of (Union[Unset, list[str], str]): Parameter for language one of.
        tags_one_of (Union[Unset, list[str], str]): Parameter for tags one of.
        tags_all_of (Union[Unset, list[str], str]): Parameter for tags all of.
        is_local (Union[Unset, bool]): Parameter for is local.
        include (Union[Unset, GetVideoChannelVideosInclude]): Parameter for include.
        has_hls_files (Union[Unset, bool]): Parameter for has hls files.
        has_web_video_files (Union[Unset, bool]): Video-related parameter.
        host (Union[Unset, str]): Parameter for host.
        auto_tag_one_of (Union[Unset, list[str], str]): Parameter for auto tag one of.
        privacy_one_of (Union[Unset, VideoPrivacySet]): privacy id of the video (see
            [/videos/privacies](#operation/getVideoPrivacyPolicies))
        exclude_already_watched (Union[Unset, bool]): Parameter for exclude already watched.
        search (Union[Unset, str]): Search query filter.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[VideoListResponse]
    """
    kwargs = _get_kwargs(
        channel_handle=channel_handle,
        start=start,
        count=count,
        skip_count=skip_count,
        sort=sort,
        nsfw=nsfw,
        nsfw_flags_included=nsfw_flags_included,
        nsfw_flags_excluded=nsfw_flags_excluded,
        is_live=is_live,
        include_scheduled_live=include_scheduled_live,
        category_one_of=category_one_of,
        licence_one_of=licence_one_of,
        language_one_of=language_one_of,
        tags_one_of=tags_one_of,
        tags_all_of=tags_all_of,
        is_local=is_local,
        include=include,
        has_hls_files=has_hls_files,
        has_web_video_files=has_web_video_files,
        host=host,
        auto_tag_one_of=auto_tag_one_of,
        privacy_one_of=privacy_one_of,
        exclude_already_watched=exclude_already_watched,
        search=search,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    channel_handle: str,
    *,
    client: AuthenticatedClient | Client,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
    skip_count: Unset
    | GetVideoChannelVideosSkipCount = GetVideoChannelVideosSkipCount.FALSE,
    sort: Unset | GetVideoChannelVideosSort = UNSET,
    nsfw: Unset | GetVideoChannelVideosNsfw = UNSET,
    nsfw_flags_included: Unset | NSFWFlag = UNSET,
    nsfw_flags_excluded: Unset | NSFWFlag = UNSET,
    is_live: Unset | bool = UNSET,
    include_scheduled_live: Unset | bool = UNSET,
    category_one_of: Unset | int | list[int] = UNSET,
    licence_one_of: Unset | int | list[int] = UNSET,
    language_one_of: Unset | list[str] | str = UNSET,
    tags_one_of: Unset | list[str] | str = UNSET,
    tags_all_of: Unset | list[str] | str = UNSET,
    is_local: Unset | bool = UNSET,
    include: Unset | GetVideoChannelVideosInclude = UNSET,
    has_hls_files: Unset | bool = UNSET,
    has_web_video_files: Unset | bool = UNSET,
    host: Unset | str = UNSET,
    auto_tag_one_of: Unset | list[str] | str = UNSET,
    privacy_one_of: Unset | VideoPrivacySet = UNSET,
    exclude_already_watched: Unset | bool = UNSET,
    search: Unset | str = UNSET,
) -> VideoListResponse | None:
    """List videos of a video channel


    Args:
        channel_handle (str):  Example: my_username | my_username@example.com.
        start (Union[Unset, int]): Starting index for pagination.
        count (Union[Unset, int]):  Default: 15.
        skip_count (Union[Unset, GetVideoChannelVideosSkipCount]):  Default:
            GetVideoChannelVideosSkipCount.FALSE.
        sort (Union[Unset, GetVideoChannelVideosSort]): Sort videos by criteria (prefixing with
            `-` means `DESC` order):
              * `hot` - Adaptation of Reddit "hot" algorithm taking into account video views, likes, dislikes and comments and publication date
              * `best` - Same than `hot`, but also takes into account user video history
              * `trending` - Sort videos by recent views ("recent" is defined by the admin)
              * `views` - Sort videos using their `views` counter
              * `publishedAt` - Sort by video publication date (when it became publicly available)
        nsfw (Union[Unset, GetVideoChannelVideosNsfw]): Parameter for nsfw.
        nsfw_flags_included (Union[Unset, NSFWFlag]): Parameter for nsfw flags included.
            NSFW flags (can be combined using bitwise or operator)
            - `0` NONE
            - `1` VIOLENT
            - `2` EXPLICIT_SEX
        nsfw_flags_excluded (Union[Unset, NSFWFlag]): Parameter for nsfw flags excluded.
            NSFW flags (can be combined using bitwise or operator)
            - `0` NONE
            - `1` VIOLENT
            - `2` EXPLICIT_SEX
        is_live (Union[Unset, bool]): Parameter for is live.
        include_scheduled_live (Union[Unset, bool]): Parameter for include scheduled live.
        category_one_of (Union[Unset, int, list[int]]): Parameter for category one of.
        licence_one_of (Union[Unset, int, list[int]]): Parameter for licence one of.
        language_one_of (Union[Unset, list[str], str]): Parameter for language one of.
        tags_one_of (Union[Unset, list[str], str]): Parameter for tags one of.
        tags_all_of (Union[Unset, list[str], str]): Parameter for tags all of.
        is_local (Union[Unset, bool]): Parameter for is local.
        include (Union[Unset, GetVideoChannelVideosInclude]): Parameter for include.
        has_hls_files (Union[Unset, bool]): Parameter for has hls files.
        has_web_video_files (Union[Unset, bool]): Video-related parameter.
        host (Union[Unset, str]): Parameter for host.
        auto_tag_one_of (Union[Unset, list[str], str]): Parameter for auto tag one of.
        privacy_one_of (Union[Unset, VideoPrivacySet]): privacy id of the video (see
            [/videos/privacies](#operation/getVideoPrivacyPolicies))
        exclude_already_watched (Union[Unset, bool]): Parameter for exclude already watched.
        search (Union[Unset, str]): Search query filter.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        VideoListResponse
    """
    return (
        await asyncio_detailed(
            channel_handle=channel_handle,
            client=client,
            start=start,
            count=count,
            skip_count=skip_count,
            sort=sort,
            nsfw=nsfw,
            nsfw_flags_included=nsfw_flags_included,
            nsfw_flags_excluded=nsfw_flags_excluded,
            is_live=is_live,
            include_scheduled_live=include_scheduled_live,
            category_one_of=category_one_of,
            licence_one_of=licence_one_of,
            language_one_of=language_one_of,
            tags_one_of=tags_one_of,
            tags_all_of=tags_all_of,
            is_local=is_local,
            include=include,
            has_hls_files=has_hls_files,
            has_web_video_files=has_web_video_files,
            host=host,
            auto_tag_one_of=auto_tag_one_of,
            privacy_one_of=privacy_one_of,
            exclude_already_watched=exclude_already_watched,
            search=search,
        )
    ).parsed



import datetime
from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse
from typing_extensions import Self

from peertube.models.file_redundancy_information_strategy import (
    FileRedundancyInformationStrategy,
)
from peertube.types import UNSET, Unset

T = TypeVar("T", bound="FileRedundancyInformation")


@_attrs_define
class FileRedundancyInformation:
    """Attributes:
    id (Union[Unset, int]):  Example: 42.
    file_url (Union[Unset, str]):
    strategy (Union[Unset, FileRedundancyInformationStrategy]):
    size (Union[Unset, int]):
    created_at (Union[Unset, datetime.datetime]):
    updated_at (Union[Unset, datetime.datetime]):
    expires_on (Union[Unset, datetime.datetime]):
    """

    id: Unset | int = UNSET
    file_url: Unset | str = UNSET
    strategy: Unset | FileRedundancyInformationStrategy = UNSET
    size: Unset | int = UNSET
    created_at: Unset | datetime.datetime = UNSET
    updated_at: Unset | datetime.datetime = UNSET
    expires_on: Unset | datetime.datetime = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        id = self.id

        file_url = self.file_url

        strategy: Unset | str = UNSET
        if not isinstance(self.strategy, Unset):
            strategy = self.strategy.value

        size = self.size

        created_at: Unset | str = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Unset | str = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        expires_on: Unset | str = UNSET
        if not isinstance(self.expires_on, Unset):
            expires_on = self.expires_on.isoformat()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if file_url is not UNSET:
            field_dict["fileUrl"] = file_url
        if strategy is not UNSET:
            field_dict["strategy"] = strategy
        if size is not UNSET:
            field_dict["size"] = size
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at
        if expires_on is not UNSET:
            field_dict["expiresOn"] = expires_on

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        d = dict(src_dict)
        id = d.pop("id", UNSET)

        file_url = d.pop("fileUrl", UNSET)

        _strategy = d.pop("strategy", UNSET)
        strategy: Unset | FileRedundancyInformationStrategy
        if isinstance(_strategy, Unset):
            strategy = UNSET
        else:
            strategy = FileRedundancyInformationStrategy(_strategy)

        size = d.pop("size", UNSET)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Unset | datetime.datetime
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = d.pop("updatedAt", UNSET)
        updated_at: Unset | datetime.datetime
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        _expires_on = d.pop("expiresOn", UNSET)
        expires_on: Unset | datetime.datetime
        if isinstance(_expires_on, Unset):
            expires_on = UNSET
        else:
            expires_on = isoparse(_expires_on)

        file_redundancy_information = cls(
            id=id,
            file_url=file_url,
            strategy=strategy,
            size=size,
            created_at=created_at,
            updated_at=updated_at,
            expires_on=expires_on,
        )

        file_redundancy_information.additional_properties = d
        return file_redundancy_information

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.models.live_video_latency_mode import LiveVideoLatencyMode
from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.live_schedule import LiveSchedule
    from peertube.models.live_video_replay_settings import LiveVideoReplaySettings


T = TypeVar("T", bound="LiveVideoResponse")


@_attrs_define
class LiveVideoResponse:
    """Attributes:
    rtmp_url (Union[Unset, str]): Included in the response if an appropriate token is provided
    rtmps_url (Union[Unset, str]): Included in the response if an appropriate token is provided
    stream_key (Union[Unset, str]): RTMP stream key to use to stream into this live video. Included in the response
        if an appropriate token is provided
    save_replay (Union[Unset, bool]):
    replay_settings (Union[Unset, LiveVideoReplaySettings]):
    permanent_live (Union[Unset, bool]): User can stream multiple times in a permanent live
    latency_mode (Union[Unset, LiveVideoLatencyMode]): The live latency mode (Default=`1`, High latency=`2`, Small Latency=`3`)
    schedules (Union[Unset, list['LiveSchedule']]):
    """

    rtmp_url: Unset | str = UNSET
    rtmps_url: Unset | str = UNSET
    stream_key: Unset | str = UNSET
    save_replay: Unset | bool = UNSET
    replay_settings: Union[Unset, "LiveVideoReplaySettings"] = UNSET
    permanent_live: Unset | bool = UNSET
    latency_mode: Unset | LiveVideoLatencyMode = UNSET
    schedules: Unset | list["LiveSchedule"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        rtmp_url = self.rtmp_url

        rtmps_url = self.rtmps_url

        stream_key = self.stream_key

        save_replay = self.save_replay

        replay_settings: Unset | dict[str, Any] = UNSET
        if not isinstance(self.replay_settings, Unset):
            replay_settings = self.replay_settings.to_dict()

        permanent_live = self.permanent_live

        latency_mode: Unset | int = UNSET
        if not isinstance(self.latency_mode, Unset):
            latency_mode = self.latency_mode.value

        schedules: Unset | list[dict[str, Any]] = UNSET
        if not isinstance(self.schedules, Unset):
            schedules = []
            for schedules_item_data in self.schedules:
                schedules_item = schedules_item_data.to_dict()
                schedules.append(schedules_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if rtmp_url is not UNSET:
            field_dict["rtmpUrl"] = rtmp_url
        if rtmps_url is not UNSET:
            field_dict["rtmpsUrl"] = rtmps_url
        if stream_key is not UNSET:
            field_dict["streamKey"] = stream_key
        if save_replay is not UNSET:
            field_dict["saveReplay"] = save_replay
        if replay_settings is not UNSET:
            field_dict["replaySettings"] = replay_settings
        if permanent_live is not UNSET:
            field_dict["permanentLive"] = permanent_live
        if latency_mode is not UNSET:
            field_dict["latencyMode"] = latency_mode
        if schedules is not UNSET:
            field_dict["schedules"] = schedules

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.live_schedule import LiveSchedule
        from peertube.models.live_video_replay_settings import LiveVideoReplaySettings

        d = dict(src_dict)
        rtmp_url = d.pop("rtmpUrl", UNSET)

        rtmps_url = d.pop("rtmpsUrl", UNSET)

        stream_key = d.pop("streamKey", UNSET)

        save_replay = d.pop("saveReplay", UNSET)

        _replay_settings = d.pop("replaySettings", UNSET)
        replay_settings: Unset | LiveVideoReplaySettings
        if isinstance(_replay_settings, Unset):
            replay_settings = UNSET
        else:
            replay_settings = LiveVideoReplaySettings.from_dict(_replay_settings)

        permanent_live = d.pop("permanentLive", UNSET)

        _latency_mode = d.pop("latencyMode", UNSET)
        latency_mode: Unset | LiveVideoLatencyMode
        if isinstance(_latency_mode, Unset):
            latency_mode = UNSET
        else:
            latency_mode = LiveVideoLatencyMode(_latency_mode)

        schedules = []
        _schedules = d.pop("schedules", UNSET)
        for schedules_item_data in _schedules or []:
            schedules_item = LiveSchedule.from_dict(schedules_item_data)

            schedules.append(schedules_item)

        live_video_response = cls(
            rtmp_url=rtmp_url,
            rtmps_url=rtmps_url,
            stream_key=stream_key,
            save_replay=save_replay,
            replay_settings=replay_settings,
            permanent_live=permanent_live,
            latency_mode=latency_mode,
            schedules=schedules,
        )

        live_video_response.additional_properties = d
        return live_video_response

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

T = TypeVar("T", bound="ServerConfigInstanceSocial")


@_attrs_define
class ServerConfigInstanceSocial:
    """Attributes:
    external_link (Union[Unset, str]):
    mastodon_link (Union[Unset, str]):
    bluesky_link (Union[Unset, str]):
    x_link (Union[Unset, str]):
    """

    external_link: Unset | str = UNSET
    mastodon_link: Unset | str = UNSET
    bluesky_link: Unset | str = UNSET
    x_link: Unset | str = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        external_link = self.external_link

        mastodon_link = self.mastodon_link

        bluesky_link = self.bluesky_link

        x_link = self.x_link

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if external_link is not UNSET:
            field_dict["externalLink"] = external_link
        if mastodon_link is not UNSET:
            field_dict["mastodonLink"] = mastodon_link
        if bluesky_link is not UNSET:
            field_dict["blueskyLink"] = bluesky_link
        if x_link is not UNSET:
            field_dict["xLink"] = x_link

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        d = dict(src_dict)
        external_link = d.pop("externalLink", UNSET)

        mastodon_link = d.pop("mastodonLink", UNSET)

        bluesky_link = d.pop("blueskyLink", UNSET)

        x_link = d.pop("xLink", UNSET)

        server_config_instance_social = cls(
            external_link=external_link,
            mastodon_link=mastodon_link,
            bluesky_link=bluesky_link,
            x_link=x_link,
        )

        server_config_instance_social.additional_properties = d
        return server_config_instance_social

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

T = TypeVar("T", bound="VideoChannelSyncCreate")


@_attrs_define
class VideoChannelSyncCreate:
    """Attributes:
    external_channel_url (Union[Unset, str]):  Example: https://youtube.com/c/UC_myfancychannel.
    video_channel_id (Union[Unset, int]):  Example: 42.
    """

    external_channel_url: Unset | str = UNSET
    video_channel_id: Unset | int = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert to dictionary."""

        external_channel_url = self.external_channel_url

        video_channel_id = self.video_channel_id

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if external_channel_url is not UNSET:
            field_dict["externalChannelUrl"] = external_channel_url
        if video_channel_id is not UNSET:
            field_dict["videoChannelId"] = video_channel_id

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create from dictionary."""

        d = dict(src_dict)
        external_channel_url = d.pop("externalChannelUrl", UNSET)

        video_channel_id = d.pop("videoChannelId", UNSET)

        video_channel_sync_create = cls(
            external_channel_url=external_channel_url, video_channel_id=video_channel_id
        )

        video_channel_sync_create.additional_properties = d
        return video_channel_sync_create

    @property
    def additional_keys(self) -> list[str]:
        """Get additional keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.video_stats_user_agent_clients_item import (
        VideoStatsUserAgentClientsItem,
    )
    from peertube.models.video_stats_user_agent_devices_item import (
        VideoStatsUserAgentDevicesItem,
    )
    from peertube.models.video_stats_user_agent_operating_system_item import (
        VideoStatsUserAgentOperatingSystemItem,
    )


T = TypeVar("T", bound="VideoStatsUserAgent")


@_attrs_define
class VideoStatsUserAgent:
    """Attributes:
    clients (Union[Unset, list['VideoStatsUserAgentClientsItem']]):
    devices (Union[Unset, list['VideoStatsUserAgentDevicesItem']]):
    operating_system (Union[Unset, list['VideoStatsUserAgentOperatingSystemItem']]):
    """

    clients: Unset | list["VideoStatsUserAgentClientsItem"] = UNSET
    devices: Unset | list["VideoStatsUserAgentDevicesItem"] = UNSET
    operating_system: Unset | list["VideoStatsUserAgentOperatingSystemItem"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        clients: Unset | list[dict[str, Any]] = UNSET
        if not isinstance(self.clients, Unset):
            clients = []
            for clients_item_data in self.clients:
                clients_item = clients_item_data.to_dict()
                clients.append(clients_item)

        devices: Unset | list[dict[str, Any]] = UNSET
        if not isinstance(self.devices, Unset):
            devices = []
            for devices_item_data in self.devices:
                devices_item = devices_item_data.to_dict()
                devices.append(devices_item)

        operating_system: Unset | list[dict[str, Any]] = UNSET
        if not isinstance(self.operating_system, Unset):
            operating_system = []
            for operating_system_item_data in self.operating_system:
                operating_system_item = operating_system_item_data.to_dict()
                operating_system.append(operating_system_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if clients is not UNSET:
            field_dict["clients"] = clients
        if devices is not UNSET:
            field_dict["devices"] = devices
        if operating_system is not UNSET:
            field_dict["operatingSystem"] = operating_system

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.video_stats_user_agent_clients_item import (
            VideoStatsUserAgentClientsItem,
        )
        from peertube.models.video_stats_user_agent_devices_item import (
            VideoStatsUserAgentDevicesItem,
        )
        from peertube.models.video_stats_user_agent_operating_system_item import (
            VideoStatsUserAgentOperatingSystemItem,
        )

        d = dict(src_dict)
        clients = []
        _clients = d.pop("clients", UNSET)
        for clients_item_data in _clients or []:
            clients_item = VideoStatsUserAgentClientsItem.from_dict(clients_item_data)

            clients.append(clients_item)

        devices = []
        _devices = d.pop("devices", UNSET)
        for devices_item_data in _devices or []:
            devices_item = VideoStatsUserAgentDevicesItem.from_dict(devices_item_data)

            devices.append(devices_item)

        operating_system = []
        _operating_system = d.pop("operatingSystem", UNSET)
        for operating_system_item_data in _operating_system or []:
            operating_system_item = VideoStatsUserAgentOperatingSystemItem.from_dict(
                operating_system_item_data
            )

            operating_system.append(operating_system_item)

        video_stats_user_agent = cls(
            clients=clients, devices=devices, operating_system=operating_system
        )

        video_stats_user_agent.additional_properties = d
        return video_stats_user_agent

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class GetMyAbusesSort(str, Enum):
    """GetMyAbusesSort enumeration."""

    VALUE_0 = "-id"
    VALUE_1 = "-createdAt"
    VALUE_2 = "-state"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class ListRegistrationsSort(str, Enum):
    """ListRegistrationsSort enumeration."""

    CREATEDAT = "createdAt"
    STATE = "state"
    VALUE_0 = "-createdAt"
    VALUE_3 = "-state"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

T = TypeVar("T", bound="ReorderVideoPlaylistsOfChannelBody")


@_attrs_define
class ReorderVideoPlaylistsOfChannelBody:
    """Attributes:
    start_position (int): Start position of the element to reorder
    insert_after_position (int): New position for the block to reorder, to add the block before the first element
    reorder_length (Union[Unset, int]): How many element from `startPosition` to reorder
    """

    start_position: int
    insert_after_position: int
    reorder_length: Unset | int = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        start_position = self.start_position

        insert_after_position = self.insert_after_position

        reorder_length = self.reorder_length

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "startPosition": start_position,
                "insertAfterPosition": insert_after_position,
            }
        )
        if reorder_length is not UNSET:
            field_dict["reorderLength"] = reorder_length

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        d = dict(src_dict)
        start_position = d.pop("startPosition")

        insert_after_position = d.pop("insertAfterPosition")

        reorder_length = d.pop("reorderLength", UNSET)

        reorder_video_playlists_of_channel_body = cls(
            start_position=start_position,
            insert_after_position=insert_after_position,
            reorder_length=reorder_length,
        )

        reorder_video_playlists_of_channel_body.additional_properties = d
        return reorder_video_playlists_of_channel_body

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



"""Contains all the data models used in inputs/outputs"""

from .abuse_message import AbuseMessage
from .abuse_predefined_reasons_item import AbusePredefinedReasonsItem
from .abuse_state_constant import AbuseStateConstant
from .abuse_state_set import AbuseStateSet
from .account_summary import AccountSummary
from .actor import Actor
from .actor_image import ActorImage
from .actor_info import ActorInfo
from .add_intro_name import AddIntroName
from .add_intro_options import AddIntroOptions
from .add_live_body import AddLiveBody
from .add_outro_name import AddOutroName
from .add_outro_options import AddOutroOptions
from .add_playlist_body import AddPlaylistBody
from .add_plugin_body_type_0 import AddPluginBodyType0
from .add_plugin_body_type_1 import AddPluginBodyType1
from .add_user import AddUser
from .add_user_response import AddUserResponse
from .add_user_response_user import AddUserResponseUser
from .add_user_response_user_account import AddUserResponseUserAccount
from .add_video_caption_body import AddVideoCaptionBody
from .add_video_channel_response_200 import AddVideoChannelResponse200
from .add_video_channel_response_200_video_channel import (
    AddVideoChannelResponse200VideoChannel,
)
from .add_watermark_name import AddWatermarkName
from .add_watermark_options import AddWatermarkOptions
from .automatic_tag_available import AutomaticTagAvailable
from .automatic_tag_available_available_item import AutomaticTagAvailableAvailableItem
from .automatic_tag_available_available_item_type import (
    AutomaticTagAvailableAvailableItemType,
)
from .block_status import BlockStatus
from .block_status_accounts import BlockStatusAccounts
from .block_status_accounts_additional_property import (
    BlockStatusAccountsAdditionalProperty,
)
from .block_status_hosts import BlockStatusHosts
from .block_status_hosts_additional_property import BlockStatusHostsAdditionalProperty
from .comment_auto_tag_policies import CommentAutoTagPolicies
from .confirm_two_factor_request_body import ConfirmTwoFactorRequestBody
from .create_video_transcoding_body import CreateVideoTranscodingBody
from .create_video_transcoding_body_transcoding_type import (
    CreateVideoTranscodingBodyTranscodingType,
)
from .custom_homepage import CustomHomepage
from .cut_name import CutName
from .cut_options import CutOptions
from .delete_api_v1_config_instance_logo_logo_type_logo_type import (
    DeleteApiV1ConfigInstanceLogoLogoTypeLogoType,
)
from .delete_api_v1_runners_runner_id_body import DeleteApiV1RunnersRunnerIdBody
from .disable_two_factor_body import DisableTwoFactorBody
from .file_redundancy_information import FileRedundancyInformation
from .file_redundancy_information_strategy import FileRedundancyInformationStrategy
from .file_storage import FileStorage
from .follow import Follow
from .follow_state import FollowState
from .generate_video_caption_body import GenerateVideoCaptionBody
from .get_abuses_filter import GetAbusesFilter
from .get_abuses_sort import GetAbusesSort
from .get_abuses_video_is import GetAbusesVideoIs
from .get_account_followers_response_200 import GetAccountFollowersResponse200
from .get_account_followers_sort import GetAccountFollowersSort
from .get_account_videos_include import GetAccountVideosInclude
from .get_account_videos_nsfw import GetAccountVideosNsfw
from .get_account_videos_skip_count import GetAccountVideosSkipCount
from .get_account_videos_sort import GetAccountVideosSort
from .get_api_v1_accounts_name_ratings_rating import GetApiV1AccountsNameRatingsRating
from .get_api_v1_accounts_name_video_playlists_response_200 import (
    GetApiV1AccountsNameVideoPlaylistsResponse200,
)
from .get_api_v1_plugins_npm_name_public_settings_response_200 import (
    GetApiV1PluginsNpmNamePublicSettingsResponse200,
)
from .get_api_v1_plugins_npm_name_registered_settings_response_200 import (
    GetApiV1PluginsNpmNameRegisteredSettingsResponse200,
)
from .get_api_v1_runners_jobs_response_200 import GetApiV1RunnersJobsResponse200
from .get_api_v1_runners_jobs_sort import GetApiV1RunnersJobsSort
from .get_api_v1_runners_registration_tokens_response_200 import (
    GetApiV1RunnersRegistrationTokensResponse200,
)
from .get_api_v1_runners_registration_tokens_sort import (
    GetApiV1RunnersRegistrationTokensSort,
)
from .get_api_v1_runners_response_200 import GetApiV1RunnersResponse200
from .get_api_v1_runners_sort import GetApiV1RunnersSort
from .get_api_v1_server_followers_actor_type import GetApiV1ServerFollowersActorType
from .get_api_v1_server_followers_response_200 import GetApiV1ServerFollowersResponse200
from .get_api_v1_server_followers_state import GetApiV1ServerFollowersState
from .get_api_v1_server_following_actor_type import GetApiV1ServerFollowingActorType
from .get_api_v1_server_following_response_200 import GetApiV1ServerFollowingResponse200
from .get_api_v1_server_following_state import GetApiV1ServerFollowingState
from .get_api_v1_users_id_token_sessions_response_200 import (
    GetApiV1UsersIdTokenSessionsResponse200,
)
from .get_api_v1_users_me_subscriptions_exist_response_200 import (
    GetApiV1UsersMeSubscriptionsExistResponse200,
)
from .get_api_v1_users_me_subscriptions_sort import GetApiV1UsersMeSubscriptionsSort
from .get_api_v1_users_me_subscriptions_videos_include import (
    GetApiV1UsersMeSubscriptionsVideosInclude,
)
from .get_api_v1_users_me_subscriptions_videos_nsfw import (
    GetApiV1UsersMeSubscriptionsVideosNsfw,
)
from .get_api_v1_users_me_subscriptions_videos_skip_count import (
    GetApiV1UsersMeSubscriptionsVideosSkipCount,
)
from .get_api_v1_users_me_subscriptions_videos_sort import (
    GetApiV1UsersMeSubscriptionsVideosSort,
)
from .get_api_v1_users_me_video_quota_used_response_200 import (
    GetApiV1UsersMeVideoQuotaUsedResponse200,
)
from .get_api_v1_users_me_videos_include import GetApiV1UsersMeVideosInclude
from .get_api_v1_users_me_videos_nsfw import GetApiV1UsersMeVideosNsfw
from .get_api_v1_users_me_videos_skip_count import GetApiV1UsersMeVideosSkipCount
from .get_api_v1_users_me_videos_sort import GetApiV1UsersMeVideosSort
from .get_api_v1_video_channels_channel_handle_video_playlists_response_200 import (
    GetApiV1VideoChannelsChannelHandleVideoPlaylistsResponse200,
)
from .get_api_v1_videos_id_comment_threads_sort import (
    GetApiV1VideosIdCommentThreadsSort,
)
from .get_api_v1_videos_id_stats_timeseries_metric_metric import (
    GetApiV1VideosIdStatsTimeseriesMetricMetric,
)
from .get_api_v1_videos_live_id_sessions_response_200 import (
    GetApiV1VideosLiveIdSessionsResponse200,
)
from .get_api_v1_watched_words_accounts_account_name_lists_response_200 import (
    GetApiV1WatchedWordsAccountsAccountNameListsResponse200,
)
from .get_api_v1_watched_words_server_lists_response_200 import (
    GetApiV1WatchedWordsServerListsResponse200,
)
from .get_jobs_job_type import GetJobsJobType
from .get_jobs_response_200 import GetJobsResponse200
from .get_jobs_state import GetJobsState
from .get_latest_user_import_response_200 import GetLatestUserImportResponse200
from .get_latest_user_import_response_200_state import (
    GetLatestUserImportResponse200State,
)
from .get_me_video_rating import GetMeVideoRating
from .get_me_video_rating_rating import GetMeVideoRatingRating
from .get_mirrored_videos_sort import GetMirroredVideosSort
from .get_mirrored_videos_target import GetMirroredVideosTarget
from .get_my_abuses_sort import GetMyAbusesSort
from .get_o_auth_token_response_200 import GetOAuthTokenResponse200
from .get_playlists_response_200 import GetPlaylistsResponse200
from .get_syndicated_comments_format import GetSyndicatedCommentsFormat
from .get_syndicated_subscription_videos_format import (
    GetSyndicatedSubscriptionVideosFormat,
)
from .get_syndicated_subscription_videos_include import (
    GetSyndicatedSubscriptionVideosInclude,
)
from .get_syndicated_subscription_videos_nsfw import GetSyndicatedSubscriptionVideosNsfw
from .get_syndicated_videos_format import GetSyndicatedVideosFormat
from .get_syndicated_videos_include import GetSyndicatedVideosInclude
from .get_syndicated_videos_nsfw import GetSyndicatedVideosNsfw
from .get_users_sort import GetUsersSort
from .get_video_blocks_sort import GetVideoBlocksSort
from .get_video_blocks_type import GetVideoBlocksType
from .get_video_captions_response_200 import GetVideoCaptionsResponse200
from .get_video_channel_followers_response_200 import (
    GetVideoChannelFollowersResponse200,
)
from .get_video_channel_followers_sort import GetVideoChannelFollowersSort
from .get_video_channel_videos_include import GetVideoChannelVideosInclude
from .get_video_channel_videos_nsfw import GetVideoChannelVideosNsfw
from .get_video_channel_videos_skip_count import GetVideoChannelVideosSkipCount
from .get_video_channel_videos_sort import GetVideoChannelVideosSort
from .get_videos_include import GetVideosInclude
from .get_videos_nsfw import GetVideosNsfw
from .get_videos_skip_count import GetVideosSkipCount
from .get_videos_sort import GetVideosSort
from .import_videos_in_channel_create import ImportVideosInChannelCreate
from .job import Job
from .job_data import JobData
from .job_error import JobError
from .job_state import JobState
from .job_type import JobType
from .list_registrations_response_200 import ListRegistrationsResponse200
from .list_registrations_sort import ListRegistrationsSort
from .list_user_exports_response_200 import ListUserExportsResponse200
from .list_user_exports_response_200_state import ListUserExportsResponse200State
from .list_video_storyboards_response_200 import ListVideoStoryboardsResponse200
from .live_schedule import LiveSchedule
from .live_video_latency_mode import LiveVideoLatencyMode
from .live_video_replay_settings import LiveVideoReplaySettings
from .live_video_response import LiveVideoResponse
from .live_video_session_response import LiveVideoSessionResponse
from .live_video_session_response_error import LiveVideoSessionResponseError
from .live_video_session_response_replay_video import (
    LiveVideoSessionResponseReplayVideo,
)
from .live_video_update import LiveVideoUpdate
from .mrss_group_content import MRSSGroupContent
from .mrss_peer_link import MRSSPeerLink
from .mrss_peer_link_type import MRSSPeerLinkType
from .notification_type import NotificationType
from .nsfw_flag import NSFWFlag
from .nsfw_policy import NSFWPolicy
from .o_auth_client import OAuthClient
from .o_auth_token_refresh_token import OAuthTokenRefreshToken
from .o_auth_token_refresh_token_grant_type import OAuthTokenRefreshTokenGrantType
from .playback_metric_create import PlaybackMetricCreate
from .playback_metric_create_player_mode import PlaybackMetricCreatePlayerMode
from .playlist_element import PlaylistElement
from .plugin import Plugin
from .plugin_response import PluginResponse
from .plugin_settings import PluginSettings
from .plugin_type import PluginType
from .post_api_v1_abuses_response_200 import PostApiV1AbusesResponse200
from .post_api_v1_abuses_response_200_abuse import PostApiV1AbusesResponse200Abuse
from .post_api_v1_config_instance_avatar_pick_body import (
    PostApiV1ConfigInstanceAvatarPickBody,
)
from .post_api_v1_config_instance_banner_pick_body import (
    PostApiV1ConfigInstanceBannerPickBody,
)
from .post_api_v1_config_instance_logo_logo_type_pick_body import (
    PostApiV1ConfigInstanceLogoLogoTypePickBody,
)
from .post_api_v1_config_instance_logo_logo_type_pick_logo_type import (
    PostApiV1ConfigInstanceLogoLogoTypePickLogoType,
)
from .post_api_v1_runners_jobs_job_uuid_abort_body import (
    PostApiV1RunnersJobsJobUUIDAbortBody,
)
from .post_api_v1_runners_jobs_job_uuid_accept_body import (
    PostApiV1RunnersJobsJobUUIDAcceptBody,
)
from .post_api_v1_runners_jobs_job_uuid_accept_response_200 import (
    PostApiV1RunnersJobsJobUUIDAcceptResponse200,
)
from .post_api_v1_runners_jobs_job_uuid_accept_response_200_job import (
    PostApiV1RunnersJobsJobUUIDAcceptResponse200Job,
)
from .post_api_v1_runners_jobs_job_uuid_error_body import (
    PostApiV1RunnersJobsJobUUIDErrorBody,
)
from .post_api_v1_runners_jobs_job_uuid_success_body import (
    PostApiV1RunnersJobsJobUUIDSuccessBody,
)
from .post_api_v1_runners_jobs_job_uuid_success_body_live_rtmp_to_hls_transcoding import (
    PostApiV1RunnersJobsJobUUIDSuccessBodyLiveRTMPToHLSTranscoding,
)
from .post_api_v1_runners_jobs_job_uuid_success_body_vod_audio_merge_transcoding import (
    PostApiV1RunnersJobsJobUUIDSuccessBodyVODAudioMergeTranscoding,
)
from .post_api_v1_runners_jobs_job_uuid_success_body_vod_web_video_transcoding import (
    PostApiV1RunnersJobsJobUUIDSuccessBodyVODWebVideoTranscoding,
)
from .post_api_v1_runners_jobs_job_uuid_success_body_vodhls_transcoding import (
    PostApiV1RunnersJobsJobUUIDSuccessBodyVODHLSTranscoding,
)
from .post_api_v1_runners_jobs_job_uuid_update_body import (
    PostApiV1RunnersJobsJobUUIDUpdateBody,
)
from .post_api_v1_runners_jobs_job_uuid_update_body_payload_type_0 import (
    PostApiV1RunnersJobsJobUUIDUpdateBodyPayloadType0,
)
from .post_api_v1_runners_jobs_job_uuid_update_body_payload_type_0_type import (
    PostApiV1RunnersJobsJobUUIDUpdateBodyPayloadType0Type,
)
from .post_api_v1_runners_jobs_request_body import PostApiV1RunnersJobsRequestBody
from .post_api_v1_runners_jobs_request_response_200 import (
    PostApiV1RunnersJobsRequestResponse200,
)
from .post_api_v1_runners_jobs_request_response_200_available_jobs_item import (
    PostApiV1RunnersJobsRequestResponse200AvailableJobsItem,
)
from .post_api_v1_runners_register_body import PostApiV1RunnersRegisterBody
from .post_api_v1_runners_register_response_200 import (
    PostApiV1RunnersRegisterResponse200,
)
from .post_api_v1_runners_unregister_body import PostApiV1RunnersUnregisterBody
from .post_api_v1_server_blocklist_accounts_body import (
    PostApiV1ServerBlocklistAccountsBody,
)
from .post_api_v1_server_blocklist_servers_body import (
    PostApiV1ServerBlocklistServersBody,
)
from .post_api_v1_server_following_body import PostApiV1ServerFollowingBody
from .post_api_v1_users_ask_reset_password_body import (
    PostApiV1UsersAskResetPasswordBody,
)
from .post_api_v1_users_id_reset_password_body import PostApiV1UsersIdResetPasswordBody
from .post_api_v1_users_me_avatar_pick_body import PostApiV1UsersMeAvatarPickBody
from .post_api_v1_users_me_avatar_pick_response_200 import (
    PostApiV1UsersMeAvatarPickResponse200,
)
from .post_api_v1_users_me_history_videos_remove_body import (
    PostApiV1UsersMeHistoryVideosRemoveBody,
)
from .post_api_v1_users_me_notifications_read_body import (
    PostApiV1UsersMeNotificationsReadBody,
)
from .post_api_v1_users_me_subscriptions_body import PostApiV1UsersMeSubscriptionsBody
from .post_api_v1_video_channels_channel_handle_avatar_pick_body import (
    PostApiV1VideoChannelsChannelHandleAvatarPickBody,
)
from .post_api_v1_video_channels_channel_handle_avatar_pick_response_200 import (
    PostApiV1VideoChannelsChannelHandleAvatarPickResponse200,
)
from .post_api_v1_video_channels_channel_handle_banner_pick_body import (
    PostApiV1VideoChannelsChannelHandleBannerPickBody,
)
from .post_api_v1_video_channels_channel_handle_banner_pick_response_200 import (
    PostApiV1VideoChannelsChannelHandleBannerPickResponse200,
)
from .post_api_v1_videos_id_give_ownership_body import (
    PostApiV1VideosIdGiveOwnershipBody,
)
from .post_api_v1_watched_words_accounts_account_name_lists_body import (
    PostApiV1WatchedWordsAccountsAccountNameListsBody,
)
from .post_api_v1_watched_words_accounts_account_name_lists_response_200 import (
    PostApiV1WatchedWordsAccountsAccountNameListsResponse200,
)
from .post_api_v1_watched_words_accounts_account_name_lists_response_200_watched_words_list import (
    PostApiV1WatchedWordsAccountsAccountNameListsResponse200WatchedWordsList,
)
from .post_api_v1_watched_words_server_lists_body import (
    PostApiV1WatchedWordsServerListsBody,
)
from .post_api_v1_watched_words_server_lists_response_200 import (
    PostApiV1WatchedWordsServerListsResponse200,
)
from .post_api_v1_watched_words_server_lists_response_200_watched_words_list import (
    PostApiV1WatchedWordsServerListsResponse200WatchedWordsList,
)
from .predefined_abuse_reasons_item import PredefinedAbuseReasonsItem
from .put_api_v1_automatic_tags_policies_accounts_account_name_comments_body import (
    PutApiV1AutomaticTagsPoliciesAccountsAccountNameCommentsBody,
)
from .put_api_v1_custom_pages_homepage_instance_body import (
    PutApiV1CustomPagesHomepageInstanceBody,
)
from .put_api_v1_plugins_npm_name_settings_body import (
    PutApiV1PluginsNpmNameSettingsBody,
)
from .put_api_v1_plugins_npm_name_settings_body_settings import (
    PutApiV1PluginsNpmNameSettingsBodySettings,
)
from .put_api_v1_server_redundancy_host_body import PutApiV1ServerRedundancyHostBody
from .put_api_v1_users_me_notification_settings_body import (
    PutApiV1UsersMeNotificationSettingsBody,
)
from .put_api_v1_videos_id_rate_body import PutApiV1VideosIdRateBody
from .put_api_v1_videos_id_rate_body_rating import PutApiV1VideosIdRateBodyRating
from .put_api_v1_watched_words_accounts_account_name_lists_list_id_body import (
    PutApiV1WatchedWordsAccountsAccountNameListsListIdBody,
)
from .put_api_v1_watched_words_server_lists_list_id_body import (
    PutApiV1WatchedWordsServerListsListIdBody,
)
from .register_user import RegisterUser
from .register_user_channel import RegisterUserChannel
from .reorder_video_playlists_of_channel_body import ReorderVideoPlaylistsOfChannelBody
from .replace_video_chapters_body import ReplaceVideoChaptersBody
from .replace_video_chapters_body_chapters_item import (
    ReplaceVideoChaptersBodyChaptersItem,
)
from .request_two_factor_body import RequestTwoFactorBody
from .request_two_factor_response import RequestTwoFactorResponse
from .request_two_factor_response_otp_request import RequestTwoFactorResponseOtpRequest
from .request_user_export_body import RequestUserExportBody
from .request_user_export_response_200 import RequestUserExportResponse200
from .request_user_export_response_200_export import RequestUserExportResponse200Export
from .resend_email_to_verify_registration_body import (
    ResendEmailToVerifyRegistrationBody,
)
from .resend_email_to_verify_user_body import ResendEmailToVerifyUserBody
from .runner import Runner
from .runner_job import RunnerJob
from .runner_job_admin import RunnerJobAdmin
from .runner_job_admin_private_payload import RunnerJobAdminPrivatePayload
from .runner_job_parent_type_0 import RunnerJobParentType0
from .runner_job_runner import RunnerJobRunner
from .runner_job_state import RunnerJobState
from .runner_job_state_constant import RunnerJobStateConstant
from .runner_job_type import RunnerJobType
from .runner_registration_token import RunnerRegistrationToken
from .search_channels_search_target import SearchChannelsSearchTarget
from .search_playlists_response_200 import SearchPlaylistsResponse200
from .search_playlists_search_target import SearchPlaylistsSearchTarget
from .search_videos_include import SearchVideosInclude
from .search_videos_nsfw import SearchVideosNsfw
from .search_videos_search_target import SearchVideosSearchTarget
from .search_videos_skip_count import SearchVideosSkipCount
from .search_videos_sort import SearchVideosSort
from .send_client_log import SendClientLog
from .send_client_log_level import SendClientLogLevel
from .server_config import ServerConfig
from .server_config_about import ServerConfigAbout
from .server_config_about_instance import ServerConfigAboutInstance
from .server_config_auto_blacklist import ServerConfigAutoBlacklist
from .server_config_auto_blacklist_videos import ServerConfigAutoBlacklistVideos
from .server_config_auto_blacklist_videos_of_users import (
    ServerConfigAutoBlacklistVideosOfUsers,
)
from .server_config_avatar import ServerConfigAvatar
from .server_config_avatar_file import ServerConfigAvatarFile
from .server_config_avatar_file_size import ServerConfigAvatarFileSize
from .server_config_contact_form import ServerConfigContactForm
from .server_config_custom import ServerConfigCustom
from .server_config_custom_admin import ServerConfigCustomAdmin
from .server_config_custom_auto_blacklist import ServerConfigCustomAutoBlacklist
from .server_config_custom_auto_blacklist_videos import (
    ServerConfigCustomAutoBlacklistVideos,
)
from .server_config_custom_auto_blacklist_videos_of_users import (
    ServerConfigCustomAutoBlacklistVideosOfUsers,
)
from .server_config_custom_cache import ServerConfigCustomCache
from .server_config_custom_cache_captions import ServerConfigCustomCacheCaptions
from .server_config_custom_cache_previews import ServerConfigCustomCachePreviews
from .server_config_custom_contact_form import ServerConfigCustomContactForm
from .server_config_custom_defaults import ServerConfigCustomDefaults
from .server_config_custom_defaults_p2p import ServerConfigCustomDefaultsP2P
from .server_config_custom_defaults_p2p_embed import ServerConfigCustomDefaultsP2PEmbed
from .server_config_custom_defaults_p2p_webapp import (
    ServerConfigCustomDefaultsP2PWebapp,
)
from .server_config_custom_defaults_player import ServerConfigCustomDefaultsPlayer
from .server_config_custom_defaults_publish import ServerConfigCustomDefaultsPublish
from .server_config_custom_followers import ServerConfigCustomFollowers
from .server_config_custom_followers_instance import ServerConfigCustomFollowersInstance
from .server_config_custom_import import ServerConfigCustomImport
from .server_config_custom_import_video_channel_synchronization import (
    ServerConfigCustomImportVideoChannelSynchronization,
)
from .server_config_custom_import_videos import ServerConfigCustomImportVideos
from .server_config_custom_import_videos_http import ServerConfigCustomImportVideosHttp
from .server_config_custom_import_videos_torrent import (
    ServerConfigCustomImportVideosTorrent,
)
from .server_config_custom_instance import ServerConfigCustomInstance
from .server_config_custom_instance_customizations import (
    ServerConfigCustomInstanceCustomizations,
)
from .server_config_custom_instance_social import ServerConfigCustomInstanceSocial
from .server_config_custom_instance_support import ServerConfigCustomInstanceSupport
from .server_config_custom_services import ServerConfigCustomServices
from .server_config_custom_services_twitter import ServerConfigCustomServicesTwitter
from .server_config_custom_signup import ServerConfigCustomSignup
from .server_config_custom_storyboard import ServerConfigCustomStoryboard
from .server_config_custom_theme import ServerConfigCustomTheme
from .server_config_custom_transcoding import ServerConfigCustomTranscoding
from .server_config_custom_transcoding_hls import ServerConfigCustomTranscodingHls
from .server_config_custom_transcoding_original_file import (
    ServerConfigCustomTranscodingOriginalFile,
)
from .server_config_custom_transcoding_profile import (
    ServerConfigCustomTranscodingProfile,
)
from .server_config_custom_transcoding_resolutions import (
    ServerConfigCustomTranscodingResolutions,
)
from .server_config_custom_transcoding_web_videos import (
    ServerConfigCustomTranscodingWebVideos,
)
from .server_config_custom_user import ServerConfigCustomUser
from .server_config_email import ServerConfigEmail
from .server_config_export import ServerConfigExport
from .server_config_export_users import ServerConfigExportUsers
from .server_config_federation import ServerConfigFederation
from .server_config_followings import ServerConfigFollowings
from .server_config_followings_instance import ServerConfigFollowingsInstance
from .server_config_followings_instance_auto_follow_index import (
    ServerConfigFollowingsInstanceAutoFollowIndex,
)
from .server_config_homepage import ServerConfigHomepage
from .server_config_import import ServerConfigImport
from .server_config_import_users import ServerConfigImportUsers
from .server_config_import_video_channel_synchronization import (
    ServerConfigImportVideoChannelSynchronization,
)
from .server_config_import_videos import ServerConfigImportVideos
from .server_config_import_videos_http import ServerConfigImportVideosHttp
from .server_config_import_videos_torrent import ServerConfigImportVideosTorrent
from .server_config_instance import ServerConfigInstance
from .server_config_instance_customizations import ServerConfigInstanceCustomizations
from .server_config_instance_social import ServerConfigInstanceSocial
from .server_config_instance_support import ServerConfigInstanceSupport
from .server_config_open_telemetry import ServerConfigOpenTelemetry
from .server_config_open_telemetry_metrics import ServerConfigOpenTelemetryMetrics
from .server_config_plugin import ServerConfigPlugin
from .server_config_search import ServerConfigSearch
from .server_config_search_remote_uri import ServerConfigSearchRemoteUri
from .server_config_signup import ServerConfigSignup
from .server_config_theme import ServerConfigTheme
from .server_config_tracker import ServerConfigTracker
from .server_config_transcoding import ServerConfigTranscoding
from .server_config_transcoding_hls import ServerConfigTranscodingHls
from .server_config_transcoding_web_videos import ServerConfigTranscodingWebVideos
from .server_config_trending import ServerConfigTrending
from .server_config_trending_videos import ServerConfigTrendingVideos
from .server_config_user import ServerConfigUser
from .server_config_video import ServerConfigVideo
from .server_config_video_caption import ServerConfigVideoCaption
from .server_config_video_caption_file import ServerConfigVideoCaptionFile
from .server_config_video_caption_file_size import ServerConfigVideoCaptionFileSize
from .server_config_video_file import ServerConfigVideoFile
from .server_config_video_image import ServerConfigVideoImage
from .server_config_video_image_size import ServerConfigVideoImageSize
from .server_config_views import ServerConfigViews
from .server_config_views_views import ServerConfigViewsViews
from .server_config_views_views_watching_interval import (
    ServerConfigViewsViewsWatchingInterval,
)
from .server_stats import ServerStats
from .server_stats_videos_redundancy_item import ServerStatsVideosRedundancyItem
from .storyboard import Storyboard
from .token_session import TokenSession
from .uninstall_plugin_body import UninstallPluginBody
from .update_client_language_body import UpdateClientLanguageBody
from .update_plugin_body_type_0 import UpdatePluginBodyType0
from .update_plugin_body_type_1 import UpdatePluginBodyType1
from .user_admin_flags import UserAdminFlags
from .user_export_state import UserExportState
from .user_import_resumable import UserImportResumable
from .user_import_state import UserImportState
from .user_registration import UserRegistration
from .user_registration_accept_or_reject import UserRegistrationAcceptOrReject
from .user_registration_request import UserRegistrationRequest
from .user_registration_state import UserRegistrationState
from .user_registration_state_id import UserRegistrationStateId
from .user_registration_user_type_0 import UserRegistrationUserType0
from .user_viewing_video import UserViewingVideo
from .user_viewing_video_view_event import UserViewingVideoViewEvent
from .verify_registration_email_body import VerifyRegistrationEmailBody
from .verify_user_body import VerifyUserBody
from .video import Video
from .video_caption import VideoCaption
from .video_channel_create import VideoChannelCreate
from .video_channel_edit import VideoChannelEdit
from .video_channel_summary import VideoChannelSummary
from .video_channel_sync_create import VideoChannelSyncCreate
from .video_channel_update import VideoChannelUpdate
from .video_chapters import VideoChapters
from .video_chapters_chapters import VideoChaptersChapters
from .video_comments_for_xml_item import VideoCommentsForXMLItem
from .video_comments_policy_constant import VideoCommentsPolicyConstant
from .video_comments_policy_set import VideoCommentsPolicySet
from .video_constant_number_category import VideoConstantNumberCategory
from .video_constant_number_licence import VideoConstantNumberLicence
from .video_constant_string_language import VideoConstantStringLanguage
from .video_file import VideoFile
from .video_import import VideoImport
from .video_import_state_constant import VideoImportStateConstant
from .video_import_state_constant_id import VideoImportStateConstantId
from .video_imports_list import VideoImportsList
from .video_list_response import VideoListResponse
from .video_password import VideoPassword
from .video_password_list import VideoPasswordList
from .video_playlist import VideoPlaylist
from .video_playlist_privacy_constant import VideoPlaylistPrivacyConstant
from .video_playlist_privacy_set import VideoPlaylistPrivacySet
from .video_playlist_type_constant import VideoPlaylistTypeConstant
from .video_playlist_type_set import VideoPlaylistTypeSet
from .video_privacy_constant import VideoPrivacyConstant
from .video_privacy_set import VideoPrivacySet
from .video_rating import VideoRating
from .video_rating_rating import VideoRatingRating
from .video_redundancy import VideoRedundancy
from .video_redundancy_redundancies import VideoRedundancyRedundancies
from .video_replace_source_request_resumable import VideoReplaceSourceRequestResumable
from .video_resolution_constant import VideoResolutionConstant
from .video_scheduled_update import VideoScheduledUpdate
from .video_source import VideoSource
from .video_state_constant import VideoStateConstant
from .video_state_constant_id import VideoStateConstantId
from .video_stats_overall import VideoStatsOverall
from .video_stats_overall_countries_item import VideoStatsOverallCountriesItem
from .video_stats_overall_subdivisions_item import VideoStatsOverallSubdivisionsItem
from .video_stats_retention import VideoStatsRetention
from .video_stats_retention_data_item import VideoStatsRetentionDataItem
from .video_stats_timeserie import VideoStatsTimeserie
from .video_stats_timeserie_data_item import VideoStatsTimeserieDataItem
from .video_stats_user_agent import VideoStatsUserAgent
from .video_stats_user_agent_clients_item import VideoStatsUserAgentClientsItem
from .video_stats_user_agent_device import VideoStatsUserAgentDevice
from .video_stats_user_agent_devices_item import VideoStatsUserAgentDevicesItem
from .video_stats_user_agent_operating_system_item import (
    VideoStatsUserAgentOperatingSystemItem,
)
from .video_streaming_playlists import VideoStreamingPlaylists
from .video_streaming_playlists_hls import VideoStreamingPlaylistsHLS
from .video_streaming_playlists_hls_redundancies_item import (
    VideoStreamingPlaylistsHLSRedundanciesItem,
)
from .video_streaming_playlists_type import VideoStreamingPlaylistsType
from .video_token_response import VideoTokenResponse
from .video_token_response_files import VideoTokenResponseFiles
from .video_user_history_type_0 import VideoUserHistoryType0
from .videos_for_xml_item import VideosForXMLItem
from .videos_for_xml_item_enclosure import VideosForXMLItemEnclosure
from .videos_for_xml_item_enclosure_type import VideosForXMLItemEnclosureType
from .videos_for_xml_item_mediacommunity import VideosForXMLItemMediacommunity
from .videos_for_xml_item_mediacommunity_mediastatistics import (
    VideosForXMLItemMediacommunityMediastatistics,
)
from .videos_for_xml_item_mediaembed import VideosForXMLItemMediaembed
from .videos_for_xml_item_mediaplayer import VideosForXMLItemMediaplayer
from .videos_for_xml_item_mediarating import VideosForXMLItemMediarating
from .videos_for_xml_item_mediathumbnail import VideosForXMLItemMediathumbnail
from .vod_audio_merge_transcoding_input import VODAudioMergeTranscodingInput
from .vod_audio_merge_transcoding_output import VODAudioMergeTranscodingOutput
from .vod_web_video_transcoding_input import VODWebVideoTranscodingInput
from .vod_web_video_transcoding_output import VODWebVideoTranscodingOutput
from .vodhls_transcoding_input import VODHLSTranscodingInput
from .vodhls_transcoding_output import VODHLSTranscodingOutput
from .watched_words_lists import WatchedWordsLists

__all__ = (
    "AbuseMessage",
    "AbusePredefinedReasonsItem",
    "AbuseStateConstant",
    "AbuseStateSet",
    "AccountSummary",
    "Actor",
    "ActorImage",
    "ActorInfo",
    "AddIntroName",
    "AddIntroOptions",
    "AddLiveBody",
    "AddOutroName",
    "AddOutroOptions",
    "AddPlaylistBody",
    "AddPluginBodyType0",
    "AddPluginBodyType1",
    "AddUser",
    "AddUserResponse",
    "AddUserResponseUser",
    "AddUserResponseUserAccount",
    "AddVideoCaptionBody",
    "AddVideoChannelResponse200",
    "AddVideoChannelResponse200VideoChannel",
    "AddWatermarkName",
    "AddWatermarkOptions",
    "AutomaticTagAvailable",
    "AutomaticTagAvailableAvailableItem",
    "AutomaticTagAvailableAvailableItemType",
    "BlockStatus",
    "BlockStatusAccounts",
    "BlockStatusAccountsAdditionalProperty",
    "BlockStatusHosts",
    "BlockStatusHostsAdditionalProperty",
    "CommentAutoTagPolicies",
    "ConfirmTwoFactorRequestBody",
    "CreateVideoTranscodingBody",
    "CreateVideoTranscodingBodyTranscodingType",
    "CustomHomepage",
    "CutName",
    "CutOptions",
    "DeleteApiV1ConfigInstanceLogoLogoTypeLogoType",
    "DeleteApiV1RunnersRunnerIdBody",
    "DisableTwoFactorBody",
    "FileRedundancyInformation",
    "FileRedundancyInformationStrategy",
    "FileStorage",
    "Follow",
    "FollowState",
    "GenerateVideoCaptionBody",
    "GetAbusesFilter",
    "GetAbusesSort",
    "GetAbusesVideoIs",
    "GetAccountFollowersResponse200",
    "GetAccountFollowersSort",
    "GetAccountVideosInclude",
    "GetAccountVideosNsfw",
    "GetAccountVideosSkipCount",
    "GetAccountVideosSort",
    "GetApiV1AccountsNameRatingsRating",
    "GetApiV1AccountsNameVideoPlaylistsResponse200",
    "GetApiV1PluginsNpmNamePublicSettingsResponse200",
    "GetApiV1PluginsNpmNameRegisteredSettingsResponse200",
    "GetApiV1RunnersJobsResponse200",
    "GetApiV1RunnersJobsSort",
    "GetApiV1RunnersRegistrationTokensResponse200",
    "GetApiV1RunnersRegistrationTokensSort",
    "GetApiV1RunnersResponse200",
    "GetApiV1RunnersSort",
    "GetApiV1ServerFollowersActorType",
    "GetApiV1ServerFollowersResponse200",
    "GetApiV1ServerFollowersState",
    "GetApiV1ServerFollowingActorType",
    "GetApiV1ServerFollowingResponse200",
    "GetApiV1ServerFollowingState",
    "GetApiV1UsersIdTokenSessionsResponse200",
    "GetApiV1UsersMeSubscriptionsExistResponse200",
    "GetApiV1UsersMeSubscriptionsSort",
    "GetApiV1UsersMeSubscriptionsVideosInclude",
    "GetApiV1UsersMeSubscriptionsVideosNsfw",
    "GetApiV1UsersMeSubscriptionsVideosSkipCount",
    "GetApiV1UsersMeSubscriptionsVideosSort",
    "GetApiV1UsersMeVideoQuotaUsedResponse200",
    "GetApiV1UsersMeVideosInclude",
    "GetApiV1UsersMeVideosNsfw",
    "GetApiV1UsersMeVideosSkipCount",
    "GetApiV1UsersMeVideosSort",
    "GetApiV1VideoChannelsChannelHandleVideoPlaylistsResponse200",
    "GetApiV1VideosIdCommentThreadsSort",
    "GetApiV1VideosIdStatsTimeseriesMetricMetric",
    "GetApiV1VideosLiveIdSessionsResponse200",
    "GetApiV1WatchedWordsAccountsAccountNameListsResponse200",
    "GetApiV1WatchedWordsServerListsResponse200",
    "GetJobsJobType",
    "GetJobsResponse200",
    "GetJobsState",
    "GetLatestUserImportResponse200",
    "GetLatestUserImportResponse200State",
    "GetMeVideoRating",
    "GetMeVideoRatingRating",
    "GetMirroredVideosSort",
    "GetMirroredVideosTarget",
    "GetMyAbusesSort",
    "GetOAuthTokenResponse200",
    "GetPlaylistsResponse200",
    "GetSyndicatedCommentsFormat",
    "GetSyndicatedSubscriptionVideosFormat",
    "GetSyndicatedSubscriptionVideosInclude",
    "GetSyndicatedSubscriptionVideosNsfw",
    "GetSyndicatedVideosFormat",
    "GetSyndicatedVideosInclude",
    "GetSyndicatedVideosNsfw",
    "GetUsersSort",
    "GetVideoBlocksSort",
    "GetVideoBlocksType",
    "GetVideoCaptionsResponse200",
    "GetVideoChannelFollowersResponse200",
    "GetVideoChannelFollowersSort",
    "GetVideoChannelVideosInclude",
    "GetVideoChannelVideosNsfw",
    "GetVideoChannelVideosSkipCount",
    "GetVideoChannelVideosSort",
    "GetVideosInclude",
    "GetVideosNsfw",
    "GetVideosSkipCount",
    "GetVideosSort",
    "ImportVideosInChannelCreate",
    "Job",
    "JobData",
    "JobError",
    "JobState",
    "JobType",
    "ListRegistrationsResponse200",
    "ListRegistrationsSort",
    "ListUserExportsResponse200",
    "ListUserExportsResponse200State",
    "ListVideoStoryboardsResponse200",
    "LiveSchedule",
    "LiveVideoLatencyMode",
    "LiveVideoReplaySettings",
    "LiveVideoResponse",
    "LiveVideoSessionResponse",
    "LiveVideoSessionResponseError",
    "LiveVideoSessionResponseReplayVideo",
    "LiveVideoUpdate",
    "MRSSGroupContent",
    "MRSSPeerLink",
    "MRSSPeerLinkType",
    "NSFWFlag",
    "NSFWPolicy",
    "NotificationType",
    "OAuthClient",
    "OAuthTokenRefreshToken",
    "OAuthTokenRefreshTokenGrantType",
    "PlaybackMetricCreate",
    "PlaybackMetricCreatePlayerMode",
    "PlaylistElement",
    "Plugin",
    "PluginResponse",
    "PluginSettings",
    "PluginType",
    "PostApiV1AbusesResponse200",
    "PostApiV1AbusesResponse200Abuse",
    "PostApiV1ConfigInstanceAvatarPickBody",
    "PostApiV1ConfigInstanceBannerPickBody",
    "PostApiV1ConfigInstanceLogoLogoTypePickBody",
    "PostApiV1ConfigInstanceLogoLogoTypePickLogoType",
    "PostApiV1RunnersJobsJobUUIDAbortBody",
    "PostApiV1RunnersJobsJobUUIDAcceptBody",
    "PostApiV1RunnersJobsJobUUIDAcceptResponse200",
    "PostApiV1RunnersJobsJobUUIDAcceptResponse200Job",
    "PostApiV1RunnersJobsJobUUIDErrorBody",
    "PostApiV1RunnersJobsJobUUIDSuccessBody",
    "PostApiV1RunnersJobsJobUUIDSuccessBodyLiveRTMPToHLSTranscoding",
    "PostApiV1RunnersJobsJobUUIDSuccessBodyVODAudioMergeTranscoding",
    "PostApiV1RunnersJobsJobUUIDSuccessBodyVODHLSTranscoding",
    "PostApiV1RunnersJobsJobUUIDSuccessBodyVODWebVideoTranscoding",
    "PostApiV1RunnersJobsJobUUIDUpdateBody",
    "PostApiV1RunnersJobsJobUUIDUpdateBodyPayloadType0",
    "PostApiV1RunnersJobsJobUUIDUpdateBodyPayloadType0Type",
    "PostApiV1RunnersJobsRequestBody",
    "PostApiV1RunnersJobsRequestResponse200",
    "PostApiV1RunnersJobsRequestResponse200AvailableJobsItem",
    "PostApiV1RunnersRegisterBody",
    "PostApiV1RunnersRegisterResponse200",
    "PostApiV1RunnersUnregisterBody",
    "PostApiV1ServerBlocklistAccountsBody",
    "PostApiV1ServerBlocklistServersBody",
    "PostApiV1ServerFollowingBody",
    "PostApiV1UsersAskResetPasswordBody",
    "PostApiV1UsersIdResetPasswordBody",
    "PostApiV1UsersMeAvatarPickBody",
    "PostApiV1UsersMeAvatarPickResponse200",
    "PostApiV1UsersMeHistoryVideosRemoveBody",
    "PostApiV1UsersMeNotificationsReadBody",
    "PostApiV1UsersMeSubscriptionsBody",
    "PostApiV1VideoChannelsChannelHandleAvatarPickBody",
    "PostApiV1VideoChannelsChannelHandleAvatarPickResponse200",
    "PostApiV1VideoChannelsChannelHandleBannerPickBody",
    "PostApiV1VideoChannelsChannelHandleBannerPickResponse200",
    "PostApiV1VideosIdGiveOwnershipBody",
    "PostApiV1WatchedWordsAccountsAccountNameListsBody",
    "PostApiV1WatchedWordsAccountsAccountNameListsResponse200",
    "PostApiV1WatchedWordsAccountsAccountNameListsResponse200WatchedWordsList",
    "PostApiV1WatchedWordsServerListsBody",
    "PostApiV1WatchedWordsServerListsResponse200",
    "PostApiV1WatchedWordsServerListsResponse200WatchedWordsList",
    "PredefinedAbuseReasonsItem",
    "PutApiV1AutomaticTagsPoliciesAccountsAccountNameCommentsBody",
    "PutApiV1CustomPagesHomepageInstanceBody",
    "PutApiV1PluginsNpmNameSettingsBody",
    "PutApiV1PluginsNpmNameSettingsBodySettings",
    "PutApiV1ServerRedundancyHostBody",
    "PutApiV1UsersMeNotificationSettingsBody",
    "PutApiV1VideosIdRateBody",
    "PutApiV1VideosIdRateBodyRating",
    "PutApiV1WatchedWordsAccountsAccountNameListsListIdBody",
    "PutApiV1WatchedWordsServerListsListIdBody",
    "RegisterUser",
    "RegisterUserChannel",
    "ReorderVideoPlaylistsOfChannelBody",
    "ReplaceVideoChaptersBody",
    "ReplaceVideoChaptersBodyChaptersItem",
    "RequestTwoFactorBody",
    "RequestTwoFactorResponse",
    "RequestTwoFactorResponseOtpRequest",
    "RequestUserExportBody",
    "RequestUserExportResponse200",
    "RequestUserExportResponse200Export",
    "ResendEmailToVerifyRegistrationBody",
    "ResendEmailToVerifyUserBody",
    "Runner",
    "RunnerJob",
    "RunnerJobAdmin",
    "RunnerJobAdminPrivatePayload",
    "RunnerJobParentType0",
    "RunnerJobRunner",
    "RunnerJobState",
    "RunnerJobStateConstant",
    "RunnerJobType",
    "RunnerRegistrationToken",
    "SearchChannelsSearchTarget",
    "SearchPlaylistsResponse200",
    "SearchPlaylistsSearchTarget",
    "SearchVideosInclude",
    "SearchVideosNsfw",
    "SearchVideosSearchTarget",
    "SearchVideosSkipCount",
    "SearchVideosSort",
    "SendClientLog",
    "SendClientLogLevel",
    "ServerConfig",
    "ServerConfigAbout",
    "ServerConfigAboutInstance",
    "ServerConfigAutoBlacklist",
    "ServerConfigAutoBlacklistVideos",
    "ServerConfigAutoBlacklistVideosOfUsers",
    "ServerConfigAvatar",
    "ServerConfigAvatarFile",
    "ServerConfigAvatarFileSize",
    "ServerConfigContactForm",
    "ServerConfigCustom",
    "ServerConfigCustomAdmin",
    "ServerConfigCustomAutoBlacklist",
    "ServerConfigCustomAutoBlacklistVideos",
    "ServerConfigCustomAutoBlacklistVideosOfUsers",
    "ServerConfigCustomCache",
    "ServerConfigCustomCacheCaptions",
    "ServerConfigCustomCachePreviews",
    "ServerConfigCustomContactForm",
    "ServerConfigCustomDefaults",
    "ServerConfigCustomDefaultsP2P",
    "ServerConfigCustomDefaultsP2PEmbed",
    "ServerConfigCustomDefaultsP2PWebapp",
    "ServerConfigCustomDefaultsPlayer",
    "ServerConfigCustomDefaultsPublish",
    "ServerConfigCustomFollowers",
    "ServerConfigCustomFollowersInstance",
    "ServerConfigCustomImport",
    "ServerConfigCustomImportVideoChannelSynchronization",
    "ServerConfigCustomImportVideos",
    "ServerConfigCustomImportVideosHttp",
    "ServerConfigCustomImportVideosTorrent",
    "ServerConfigCustomInstance",
    "ServerConfigCustomInstanceCustomizations",
    "ServerConfigCustomInstanceSocial",
    "ServerConfigCustomInstanceSupport",
    "ServerConfigCustomServices",
    "ServerConfigCustomServicesTwitter",
    "ServerConfigCustomSignup",
    "ServerConfigCustomStoryboard",
    "ServerConfigCustomTheme",
    "ServerConfigCustomTranscoding",
    "ServerConfigCustomTranscodingHls",
    "ServerConfigCustomTranscodingOriginalFile",
    "ServerConfigCustomTranscodingProfile",
    "ServerConfigCustomTranscodingResolutions",
    "ServerConfigCustomTranscodingWebVideos",
    "ServerConfigCustomUser",
    "ServerConfigEmail",
    "ServerConfigExport",
    "ServerConfigExportUsers",
    "ServerConfigFederation",
    "ServerConfigFollowings",
    "ServerConfigFollowingsInstance",
    "ServerConfigFollowingsInstanceAutoFollowIndex",
    "ServerConfigHomepage",
    "ServerConfigImport",
    "ServerConfigImportUsers",
    "ServerConfigImportVideoChannelSynchronization",
    "ServerConfigImportVideos",
    "ServerConfigImportVideosHttp",
    "ServerConfigImportVideosTorrent",
    "ServerConfigInstance",
    "ServerConfigInstanceCustomizations",
    "ServerConfigInstanceSocial",
    "ServerConfigInstanceSupport",
    "ServerConfigOpenTelemetry",
    "ServerConfigOpenTelemetryMetrics",
    "ServerConfigPlugin",
    "ServerConfigSearch",
    "ServerConfigSearchRemoteUri",
    "ServerConfigSignup",
    "ServerConfigTheme",
    "ServerConfigTracker",
    "ServerConfigTranscoding",
    "ServerConfigTranscodingHls",
    "ServerConfigTranscodingWebVideos",
    "ServerConfigTrending",
    "ServerConfigTrendingVideos",
    "ServerConfigUser",
    "ServerConfigVideo",
    "ServerConfigVideoCaption",
    "ServerConfigVideoCaptionFile",
    "ServerConfigVideoCaptionFileSize",
    "ServerConfigVideoFile",
    "ServerConfigVideoImage",
    "ServerConfigVideoImageSize",
    "ServerConfigViews",
    "ServerConfigViewsViews",
    "ServerConfigViewsViewsWatchingInterval",
    "ServerStats",
    "ServerStatsVideosRedundancyItem",
    "Storyboard",
    "TokenSession",
    "UninstallPluginBody",
    "UpdateClientLanguageBody",
    "UpdatePluginBodyType0",
    "UpdatePluginBodyType1",
    "UserAdminFlags",
    "UserExportState",
    "UserImportResumable",
    "UserImportState",
    "UserRegistration",
    "UserRegistrationAcceptOrReject",
    "UserRegistrationRequest",
    "UserRegistrationState",
    "UserRegistrationStateId",
    "UserRegistrationUserType0",
    "UserViewingVideo",
    "UserViewingVideoViewEvent",
    "VODAudioMergeTranscodingInput",
    "VODAudioMergeTranscodingOutput",
    "VODHLSTranscodingInput",
    "VODHLSTranscodingOutput",
    "VODWebVideoTranscodingInput",
    "VODWebVideoTranscodingOutput",
    "VerifyRegistrationEmailBody",
    "VerifyUserBody",
    "Video",
    "VideoCaption",
    "VideoChannelCreate",
    "VideoChannelEdit",
    "VideoChannelSummary",
    "VideoChannelSyncCreate",
    "VideoChannelUpdate",
    "VideoChapters",
    "VideoChaptersChapters",
    "VideoCommentsForXMLItem",
    "VideoCommentsPolicyConstant",
    "VideoCommentsPolicySet",
    "VideoConstantNumberCategory",
    "VideoConstantNumberLicence",
    "VideoConstantStringLanguage",
    "VideoFile",
    "VideoImport",
    "VideoImportStateConstant",
    "VideoImportStateConstantId",
    "VideoImportsList",
    "VideoListResponse",
    "VideoPassword",
    "VideoPasswordList",
    "VideoPlaylist",
    "VideoPlaylistPrivacyConstant",
    "VideoPlaylistPrivacySet",
    "VideoPlaylistTypeConstant",
    "VideoPlaylistTypeSet",
    "VideoPrivacyConstant",
    "VideoPrivacySet",
    "VideoRating",
    "VideoRatingRating",
    "VideoRedundancy",
    "VideoRedundancyRedundancies",
    "VideoReplaceSourceRequestResumable",
    "VideoResolutionConstant",
    "VideoScheduledUpdate",
    "VideoSource",
    "VideoStateConstant",
    "VideoStateConstantId",
    "VideoStatsOverall",
    "VideoStatsOverallCountriesItem",
    "VideoStatsOverallSubdivisionsItem",
    "VideoStatsRetention",
    "VideoStatsRetentionDataItem",
    "VideoStatsTimeserie",
    "VideoStatsTimeserieDataItem",
    "VideoStatsUserAgent",
    "VideoStatsUserAgentClientsItem",
    "VideoStatsUserAgentDevice",
    "VideoStatsUserAgentDevicesItem",
    "VideoStatsUserAgentOperatingSystemItem",
    "VideoStreamingPlaylists",
    "VideoStreamingPlaylistsHLS",
    "VideoStreamingPlaylistsHLSRedundanciesItem",
    "VideoStreamingPlaylistsType",
    "VideoTokenResponse",
    "VideoTokenResponseFiles",
    "VideoUserHistoryType0",
    "VideosForXMLItem",
    "VideosForXMLItemEnclosure",
    "VideosForXMLItemEnclosureType",
    "VideosForXMLItemMediacommunity",
    "VideosForXMLItemMediacommunityMediastatistics",
    "VideosForXMLItemMediaembed",
    "VideosForXMLItemMediaplayer",
    "VideosForXMLItemMediarating",
    "VideosForXMLItemMediathumbnail",
    "WatchedWordsLists",
)



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

if TYPE_CHECKING:
    from peertube.models.post_api_v1_runners_jobs_job_uuid_success_body_live_rtmp_to_hls_transcoding import (
        PostApiV1RunnersJobsJobUUIDSuccessBodyLiveRTMPToHLSTranscoding,
    )
    from peertube.models.post_api_v1_runners_jobs_job_uuid_success_body_vod_audio_merge_transcoding import (
        PostApiV1RunnersJobsJobUUIDSuccessBodyVODAudioMergeTranscoding,
    )
    from peertube.models.post_api_v1_runners_jobs_job_uuid_success_body_vod_web_video_transcoding import (
        PostApiV1RunnersJobsJobUUIDSuccessBodyVODWebVideoTranscoding,
    )
    from peertube.models.post_api_v1_runners_jobs_job_uuid_success_body_vodhls_transcoding import (
        PostApiV1RunnersJobsJobUUIDSuccessBodyVODHLSTranscoding,
    )


T = TypeVar("T", bound="PostApiV1RunnersJobsJobUUIDSuccessBody")


@_attrs_define
class PostApiV1RunnersJobsJobUUIDSuccessBody:
    """Attributes:
    runner_token (str):
    job_token (str):
    payload (Union['PostApiV1RunnersJobsJobUUIDSuccessBodyLiveRTMPToHLSTranscoding', 'PostApiV1RunnersJobsJobUUIDSuccessBodyVODAudioMergeTranscoding', 'PostApiV1RunnersJobsJobUUIDSuccessBodyVODHLSTranscoding', 'PostApiV1RunnersJobsJobUUIDSuccessBodyVODWebVideoTranscoding']):
    """

    runner_token: str
    job_token: str
    payload: Union[
        "PostApiV1RunnersJobsJobUUIDSuccessBodyLiveRTMPToHLSTranscoding",
        "PostApiV1RunnersJobsJobUUIDSuccessBodyVODAudioMergeTranscoding",
        "PostApiV1RunnersJobsJobUUIDSuccessBodyVODHLSTranscoding",
        "PostApiV1RunnersJobsJobUUIDSuccessBodyVODWebVideoTranscoding",
    ]
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        runner_token = self.runner_token

        job_token = self.job_token

        payload: dict[str, Any] = self.payload.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "runnerToken": runner_token,
                "jobToken": job_token,
                "payload": payload,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.post_api_v1_runners_jobs_job_uuid_success_body_live_rtmp_to_hls_transcoding import (
            PostApiV1RunnersJobsJobUUIDSuccessBodyLiveRTMPToHLSTranscoding,
        )
        from peertube.models.post_api_v1_runners_jobs_job_uuid_success_body_vod_audio_merge_transcoding import (
            PostApiV1RunnersJobsJobUUIDSuccessBodyVODAudioMergeTranscoding,
        )
        from peertube.models.post_api_v1_runners_jobs_job_uuid_success_body_vod_web_video_transcoding import (
            PostApiV1RunnersJobsJobUUIDSuccessBodyVODWebVideoTranscoding,
        )
        from peertube.models.post_api_v1_runners_jobs_job_uuid_success_body_vodhls_transcoding import (
            PostApiV1RunnersJobsJobUUIDSuccessBodyVODHLSTranscoding,
        )

        d = dict(src_dict)
        runner_token = d.pop("runnerToken")

        job_token = d.pop("jobToken")

        def _parse_payload(
            data: object,
        ) -> Union[
            "PostApiV1RunnersJobsJobUUIDSuccessBodyLiveRTMPToHLSTranscoding",
            "PostApiV1RunnersJobsJobUUIDSuccessBodyVODAudioMergeTranscoding",
            "PostApiV1RunnersJobsJobUUIDSuccessBodyVODHLSTranscoding",
            "PostApiV1RunnersJobsJobUUIDSuccessBodyVODWebVideoTranscoding",
        ]:
            try:
                if not isinstance(data, dict):
                    raise TypeError
                payload_vod_web_video_transcoding = PostApiV1RunnersJobsJobUUIDSuccessBodyVODWebVideoTranscoding.from_dict(
                    data
                )

                return payload_vod_web_video_transcoding
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError
                payload_vod_hls_transcoding = (
                    PostApiV1RunnersJobsJobUUIDSuccessBodyVODHLSTranscoding.from_dict(
                        data
                    )
                )

                return payload_vod_hls_transcoding
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError
                payload_vod_audio_merge_transcoding = PostApiV1RunnersJobsJobUUIDSuccessBodyVODAudioMergeTranscoding.from_dict(
                    data
                )

                return payload_vod_audio_merge_transcoding
            except:  # noqa: E722
                pass
            if not isinstance(data, dict):
                raise TypeError
            payload_live_rtmp_to_hls_transcoding = PostApiV1RunnersJobsJobUUIDSuccessBodyLiveRTMPToHLSTranscoding.from_dict(
                data
            )

            return payload_live_rtmp_to_hls_transcoding

        payload = _parse_payload(d.pop("payload"))

        post_api_v1_runners_jobs_job_uuid_success_body = cls(
            runner_token=runner_token, job_token=job_token, payload=payload
        )

        post_api_v1_runners_jobs_job_uuid_success_body.additional_properties = d
        return post_api_v1_runners_jobs_job_uuid_success_body

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any
from uuid import UUID

import httpx
from pydantic import ConfigDict, validate_call

from peertube import errors
from peertube.api.shared_utils import build_response
from peertube.client import AuthenticatedClient, Client
from peertube.models.put_api_v1_videos_id_rate_body import PutApiV1VideosIdRateBody
from peertube.types import UNSET, Response, Unset


def _get_kwargs(
    id: UUID | int | str,
    *,
    body: PutApiV1VideosIdRateBody,
    x_peertube_video_password: Unset | str = UNSET,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}
    if not isinstance(x_peertube_video_password, Unset):
        headers["x-peertube-video-password"] = x_peertube_video_password
    _kwargs: dict[str, Any] = {
        "method": "put",
        "url": f"/api/v1/videos/{id}/rate",
    }
    _kwargs["json"] = body.to_dict()

    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Any | None:
    if response.status_code == 204:
        return None

    if response.status_code == 404:
        return None
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[Any]:
    return build_response(client=client, response=response)


@validate_call(config=ConfigDict(arbitrary_types_allowed=True))
def sync_detailed(
    id: UUID | int | str,
    *,
    client: AuthenticatedClient,
    body: PutApiV1VideosIdRateBody,
    x_peertube_video_password: Unset | str = UNSET,
) -> Response[Any]:
    """Like/dislike a video


    Args:
        id (Union[UUID, int, str]): Unique identifier for the entity.
        x_peertube_video_password (Union[Unset, str]): Video-related parameter.
        body (PutApiV1VideosIdRateBody): Request body data.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        id=id, body=body, x_peertube_video_password=x_peertube_video_password
    )

    response = client.get_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


@validate_call(config=ConfigDict(arbitrary_types_allowed=True))
def sync(
    id: UUID | int | str,
    *,
    client: AuthenticatedClient,
    body: PutApiV1VideosIdRateBody,
    x_peertube_video_password: Unset | str = UNSET,
) -> Any | None:
    """Like/dislike a video


    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Any
    """

    return sync_detailed(
        id=id,
        client=client,
        body=body,
        x_peertube_video_password=x_peertube_video_password,
    ).parsed


@validate_call(config=ConfigDict(arbitrary_types_allowed=True))
async def asyncio_detailed(
    id: UUID | int | str,
    *,
    client: AuthenticatedClient,
    body: PutApiV1VideosIdRateBody,
    x_peertube_video_password: Unset | str = UNSET,
) -> Response[Any]:
    """Like/dislike a video


    Args:
        id (Union[UUID, int, str]): Unique identifier for the entity.
        x_peertube_video_password (Union[Unset, str]): Video-related parameter.
        body (PutApiV1VideosIdRateBody): Request body data.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        id=id, body=body, x_peertube_video_password=x_peertube_video_password
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)



import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.get_latest_user_import_response_200_state import (
        GetLatestUserImportResponse200State,
    )


T = TypeVar("T", bound="GetLatestUserImportResponse200")


@_attrs_define
class GetLatestUserImportResponse200:
    """Attributes:
    id (Union[Unset, int]):
    state (Union[Unset, GetLatestUserImportResponse200State]):
    created_at (Union[Unset, datetime.datetime]):
    """

    id: Unset | int = UNSET
    state: Union[Unset, "GetLatestUserImportResponse200State"] = UNSET
    created_at: Unset | datetime.datetime = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        id = self.id

        state: Unset | dict[str, Any] = UNSET
        if not isinstance(self.state, Unset):
            state = self.state.to_dict()

        created_at: Unset | str = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if state is not UNSET:
            field_dict["state"] = state
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.get_latest_user_import_response_200_state import (
            GetLatestUserImportResponse200State,
        )

        d = dict(src_dict)
        id = d.pop("id", UNSET)

        _state = d.pop("state", UNSET)
        state: Unset | GetLatestUserImportResponse200State
        if isinstance(_state, Unset):
            state = UNSET
        else:
            state = GetLatestUserImportResponse200State.from_dict(_state)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Unset | datetime.datetime
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        get_latest_user_import_response_200 = cls(
            id=id, state=state, created_at=created_at
        )

        get_latest_user_import_response_200.additional_properties = d
        return get_latest_user_import_response_200

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from io import BytesIO
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, File, FileTypes, Unset

T = TypeVar("T", bound="PostApiV1RunnersJobsJobUUIDSuccessBodyVODWebVideoTranscoding")


@_attrs_define
class PostApiV1RunnersJobsJobUUIDSuccessBodyVODWebVideoTranscoding:
    """Attributes:
    video_file (Union[Unset, File]):
    """

    video_file: Unset | File = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert to dictionary."""

        video_file: Unset | FileTypes = UNSET
        if not isinstance(self.video_file, Unset):
            video_file = self.video_file.to_tuple()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if video_file is not UNSET:
            field_dict["videoFile"] = video_file

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create from dictionary."""

        d = dict(src_dict)
        _video_file = d.pop("videoFile", UNSET)
        video_file: Unset | File
        if isinstance(_video_file, Unset):
            video_file = UNSET
        else:
            video_file = File(payload=BytesIO(_video_file))

        post_api_v1_runners_jobs_job_uuid_success_body_vod_web_video_transcoding = cls(
            video_file=video_file
        )

        post_api_v1_runners_jobs_job_uuid_success_body_vod_web_video_transcoding.additional_properties = d
        return post_api_v1_runners_jobs_job_uuid_success_body_vod_web_video_transcoding

    @property
    def additional_keys(self) -> list[str]:
        """Get additional keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
